searchData={"items":[{"type":"module","title":"ExDoppler","doc":"Convenience functions for interacting with Doppler\n\n<!-- tabs-open -->","ref":"ExDoppler.html"},{"type":"module","title":"📖 Resources - ExDoppler","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/secrets){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/secrets-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.html#module-resources"},{"type":"function","title":"ExDoppler.create_secret/5","doc":"Creates a new `ExDoppler.Secret`\n\n<!-- tabs-open -->","ref":"ExDoppler.html#create_secret/5"},{"type":"function","title":"🏷️ Params - ExDoppler.create_secret/5","doc":"* **project_name**: Name of the project (e.g `\"example-project\"`)\n  * **config_name**: Name of the config (e.g `\"dev_personal\"`)\n  * **new_secret_name** - Name of this new secret\n  * **value** - Value of this new secret\n  * **opts**: Optional modifications\n    * **visibility** - how the secret should appear - `:masked`, `:unmasked`, or `:restricted`. Default: `:masked`","ref":"ExDoppler.html#create_secret/5-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.create_secret/5","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.Secret{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.html#create_secret/5-returns"},{"type":"function","title":"💻 Examples - ExDoppler.create_secret/5","doc":"iex> _ = ExDoppler.delete_secret!(\"example-project\", \"dev_personal\", \"DOC_URL\")\n    iex> {:ok, _secret} = ExDoppler.create_secret(\"example-project\", \"dev_personal\", \"DOC_URL\", \"example.com\")\n    iex> {:ok, {:success, true}} = ExDoppler.delete_secret(\"example-project\", \"dev_personal\", \"DOC_URL\")","ref":"ExDoppler.html#create_secret/5-examples"},{"type":"function","title":"📖 Resources - ExDoppler.create_secret/5","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/secrets-update){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.html#create_secret/5-resources"},{"type":"function","title":"ExDoppler.create_secret!/5","doc":"Same as `create_secret/5` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.html#create_secret!/5"},{"type":"function","title":"ExDoppler.delete_secret/3","doc":"Deletes a `ExDoppler.Secret`\n\n<!-- tabs-open -->","ref":"ExDoppler.html#delete_secret/3"},{"type":"function","title":"🏷️ Params - ExDoppler.delete_secret/3","doc":"* **project_name**: Name of the project (e.g `\"example-project\"`)\n  * **config_name**: Name of the config (e.g `\"dev_personal\"`)\n  * **secret_name** - Name of secret to delete","ref":"ExDoppler.html#delete_secret/3-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.delete_secret/3","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, {:success, true}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.html#delete_secret/3-returns"},{"type":"function","title":"💻 Examples - ExDoppler.delete_secret/3","doc":"iex> _ = ExDoppler.delete_secret!(\"example-project\", \"dev_personal\", \"DOC_URL\")\n    iex> {:ok, _secret} = ExDoppler.create_secret(\"example-project\", \"dev_personal\", \"DOC_URL\", \"example.com\")\n    iex> {:ok, {:success, true}} = ExDoppler.delete_secret(\"example-project\", \"dev_personal\", \"DOC_URL\")","ref":"ExDoppler.html#delete_secret/3-examples"},{"type":"function","title":"📖 Resources - ExDoppler.delete_secret/3","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/secrets-delete){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.html#delete_secret/3-resources"},{"type":"function","title":"ExDoppler.delete_secret!/3","doc":"Same as `delete_secret/3` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.html#delete_secret!/3"},{"type":"function","title":"ExDoppler.download_secrets/3","doc":"Retrieves multiple `ExDoppler.Secret` and responds in a format ready to put into a file\n\n<!-- tabs-open -->","ref":"ExDoppler.html#download_secrets/3"},{"type":"function","title":"🏷️ Params - ExDoppler.download_secrets/3","doc":"* **project_name**: Name of the project (e.g `\"example-project\"`)\n  * **config_name**: Name of the config (e.g `\"dev_personal\"`)\n  * **opts**: Optional modifications to the download call\n    * **include_dynamic_secrets** - whether to include dynamic secrets. Default: `false`\n    * **dynamic_secrets_ttl_sec** - The number of seconds until dynamic leases expire. Must be used with include_dynamic_secrets. Defaults to 1800 (30 minutes). Default: `nil`\n    * **format** - File format to use. (e.g `\"dotnet-json\"`, `\"env\"`, `\"yaml\"`, `\"docker\"`, `\"env-no-quotes\"`) Default: `json`\n    * **name_transformer** - Transform secret names to a different case (e.g `\"camel\"`, `\"upper-camel\"`, `\"lower-snake\"`, `\"tf-var\"`, `\"dotnet\"`, `\"dotnet-env\"`, `\"lower-kebab\"`). Default: `nil`\n    * **secrets** - Comma-delimited list of secrets to include in the download. Defaults to all secrets if left unspecified.","ref":"ExDoppler.html#download_secrets/3-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.download_secrets/3","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, requested_body}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.html#download_secrets/3-returns"},{"type":"function","title":"💻 Examples - ExDoppler.download_secrets/3","doc":"iex> {:ok, _formatted_body} = ExDoppler.download_secrets(\"example-project\", \"dev_personal\", format: :env, name_transformer: \"lower-snake\")","ref":"ExDoppler.html#download_secrets/3-examples"},{"type":"function","title":"📖 Resources - ExDoppler.download_secrets/3","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/secrets-download){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.html#download_secrets/3-resources"},{"type":"function","title":"ExDoppler.download_secrets!/3","doc":"Same as `download_secrets/2` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.html#download_secrets!/3"},{"type":"function","title":"ExDoppler.get_secret/3","doc":"Retrieves a `ExDoppler.Secret`\n\n<!-- tabs-open -->","ref":"ExDoppler.html#get_secret/3"},{"type":"function","title":"🏷️ Params - ExDoppler.get_secret/3","doc":"* **project_name**: Name of the project (e.g `\"example-project\"`)\n  * **config_name**: Name of the config (e.g `\"dev_personal\"`)\n  * **secret_name** - Name of the secret to get (e.g `\"API_KEY\"`)","ref":"ExDoppler.html#get_secret/3-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.get_secret/3","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.Secret{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.html#get_secret/3-returns"},{"type":"function","title":"💻 Examples - ExDoppler.get_secret/3","doc":"iex> {:ok, _secret} = ExDoppler.get_secret(\"example-project\", \"dev_personal\", \"DB_URL\")","ref":"ExDoppler.html#get_secret/3-examples"},{"type":"function","title":"📖 Resources - ExDoppler.get_secret/3","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/secrets-get){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.html#get_secret/3-resources"},{"type":"function","title":"ExDoppler.get_secret!/3","doc":"Same as `get_secret/3` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.html#get_secret!/3"},{"type":"function","title":"ExDoppler.get_secret_raw/3","doc":"Retrieves the raw value of a  `ExDoppler.Secret`\n\n<!-- tabs-open -->","ref":"ExDoppler.html#get_secret_raw/3"},{"type":"function","title":"🏷️ Params - ExDoppler.get_secret_raw/3","doc":"* **project_name**: Name of the project (e.g `\"example-project\"`)\n  * **config_name**: Name of the config (e.g `\"dev_personal\"`)\n  * **secret_name** - Name of the secret to get (e.g `\"API_KEY\"`)","ref":"ExDoppler.html#get_secret_raw/3-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.get_secret_raw/3","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.Secret{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.html#get_secret_raw/3-returns"},{"type":"function","title":"💻 Examples - ExDoppler.get_secret_raw/3","doc":"iex> {:ok, _raw_value} = ExDoppler.get_secret_raw(\"example-project\", \"dev_personal\", \"DB_URL\")","ref":"ExDoppler.html#get_secret_raw/3-examples"},{"type":"function","title":"📖 Resources - ExDoppler.get_secret_raw/3","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/secrets-get){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.html#get_secret_raw/3-resources"},{"type":"function","title":"ExDoppler.get_secret_raw!/3","doc":"Same as `get_secret_raw/3` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.html#get_secret_raw!/3"},{"type":"function","title":"ExDoppler.list_secret_names/3","doc":"Lists the names of `ExDoppler.Secret`\n\n<!-- tabs-open -->","ref":"ExDoppler.html#list_secret_names/3"},{"type":"function","title":"🏷️ Params - ExDoppler.list_secret_names/3","doc":"* **project_name**: Name of the project (e.g `\"example-project\"`)\n  * **config_name**: Name of the config (e.g `\"dev_personal\"`)\n  * **opts**: Optional modifications to the list call\n    * **include_dynamic_secrets** - whether to include dynamic secrets. Default: `false`\n    * **include_managed_secrets** - whether to include managed secrets. Default: `true`","ref":"ExDoppler.html#list_secret_names/3-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.list_secret_names/3","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, names}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.html#list_secret_names/3-returns"},{"type":"function","title":"💻 Examples - ExDoppler.list_secret_names/3","doc":"iex> {:ok, _names} = ExDoppler.list_secret_names(\"example-project\", \"dev_personal\")","ref":"ExDoppler.html#list_secret_names/3-examples"},{"type":"function","title":"📖 Resources - ExDoppler.list_secret_names/3","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/secrets-names){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.html#list_secret_names/3-resources"},{"type":"function","title":"ExDoppler.list_secret_names!/3","doc":"Same as `list_secret_names/3` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.html#list_secret_names!/3"},{"type":"function","title":"ExDoppler.list_secrets/3","doc":"Lists `ExDoppler.Secret`\n\n<!-- tabs-open -->","ref":"ExDoppler.html#list_secrets/3"},{"type":"function","title":"🏷️ Params - ExDoppler.list_secrets/3","doc":"* **project_name**: Name of the project (e.g `\"example-project\"`)\n  * **config_name**: Name of the config (e.g `\"dev_personal\"`)\n  * **opts**: Optional modifications to the list call\n    * **include_dynamic_secrets** - whether to include dynamic secrets. Default: `false`\n    * **include_managed_secrets** - whether to include dynamic secrets. Default: `true`\n    * **secrets** - A comma-separated list of secrets to include in the response. Default: `nil`","ref":"ExDoppler.html#list_secrets/3-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.list_secrets/3","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, [%ExDoppler.Secret{...} ...]}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.html#list_secrets/3-returns"},{"type":"function","title":"💻 Examples - ExDoppler.list_secrets/3","doc":"iex> {:ok, _secrets} = ExDoppler.list_secrets(\"example-project\", \"dev_personal\")","ref":"ExDoppler.html#list_secrets/3-examples"},{"type":"function","title":"📖 Resources - ExDoppler.list_secrets/3","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/secrets-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.html#list_secrets/3-resources"},{"type":"function","title":"ExDoppler.list_secrets!/3","doc":"Same as `list_secrets/3` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.html#list_secrets!/3"},{"type":"function","title":"ExDoppler.update_secret/5","doc":"Updates a `ExDoppler.Secret`\n\n<!-- tabs-open -->","ref":"ExDoppler.html#update_secret/5"},{"type":"function","title":"🏷️ Params - ExDoppler.update_secret/5","doc":"* **project_name**: Name of the project (e.g `\"example-project\"`)\n  * **config_name**: Name of the config (e.g `\"dev_personal\"`)\n  * **secret_name** - Name of this secret\n  * **value** - Value of this secret\n  * **opts**: Optional modifications\n    * **visibility** - how the secret should appear - `:masked`, `:unmasked`, or `:restricted`. Default: `:masked`\n    * **should_promote** - Defaults to false. Can only be set to true if the config being updated is a branch config. If set to true, the provided secret will be set in both the branch config as well as the root config in that environment.\n    * **should_delete** - Defaults to false. If set to true, will delete the secret matching the name field.\n    * **should_converge** - Defaults to false. Can only be set to true if the config being updated is a branch config and there is a secret with the same name in the root config. In this case, the branch secret will inherit the value and visibility type from the root secret.","ref":"ExDoppler.html#update_secret/5-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.update_secret/5","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.Secret{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.html#update_secret/5-returns"},{"type":"function","title":"💻 Examples - ExDoppler.update_secret/5","doc":"iex> _ = ExDoppler.delete_secret!(\"example-project\", \"dev_personal\", \"DOC_URL\")\n    iex> {:ok, _secret} = ExDoppler.create_secret(\"example-project\", \"dev_personal\", \"DOC_URL\", \"example.com\")\n    iex> {:ok, _secret} = ExDoppler.update_secret(\"example-project\", \"dev_personal\", \"DOC_URL\", \"example.com2\", visibility: :unmasked)\n    iex> {:ok, {:success, true}} = ExDoppler.delete_secret(\"example-project\", \"dev_personal\", \"DOC_URL\")","ref":"ExDoppler.html#update_secret/5-examples"},{"type":"function","title":"📖 Resources - ExDoppler.update_secret/5","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/secrets-update){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.html#update_secret/5-resources"},{"type":"function","title":"ExDoppler.update_secret!/5","doc":"Same as `update_secret/5` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.html#update_secret!/5"},{"type":"function","title":"ExDoppler.update_secret_note/3","doc":"Updates the `note` field on a  `ExDoppler.Secret`\n\n<!-- tabs-open -->","ref":"ExDoppler.html#update_secret_note/3"},{"type":"function","title":"🏷️ Params - ExDoppler.update_secret_note/3","doc":"* **project_name** - Name of the associated project (e.g `\"example-project\"`)\n * **secret_name** - Name of this secret\n * **note** - Attached Note","ref":"ExDoppler.html#update_secret_note/3-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.update_secret_note/3","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %{note: note secret: %ExDoppler.Secret{...}}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.html#update_secret_note/3-returns"},{"type":"function","title":"💻 Examples - ExDoppler.update_secret_note/3","doc":"iex> _ = ExDoppler.delete_secret!(\"example-project\", \"dev_personal\", \"DOC_URL\")\n    iex> {:ok, _secret} = ExDoppler.create_secret(\"example-project\", \"dev_personal\", \"DOC_URL\", \"example.com\")\n    iex> {:ok, _secret} = ExDoppler.update_secret_note(\"example-project\", \"DOC_URL\", \"a new note\")\n    iex> {:ok, {:success, true}} = ExDoppler.delete_secret(\"example-project\", \"dev_personal\", \"DOC_URL\")","ref":"ExDoppler.html#update_secret_note/3-examples"},{"type":"function","title":"📖 Resources - ExDoppler.update_secret_note/3","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/secrets-update_note){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.html#update_secret_note/3-resources"},{"type":"function","title":"ExDoppler.update_secret_note!/3","doc":"Same as `update_secret_note/3` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.html#update_secret_note!/3"},{"type":"module","title":"ExDoppler.ActivityLogs","doc":"Module for interacting with `ExDoppler.ActivityLog`\n\n<!-- tabs-open -->","ref":"ExDoppler.ActivityLogs.html"},{"type":"module","title":"📖 Resources - ExDoppler.ActivityLogs","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/workplace-logs#activity-logs){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/activity_logs-object){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.ActivityLogs.html#module-resources"},{"type":"function","title":"ExDoppler.ActivityLogs.get_activity_log/1","doc":"Retrieves an `ExDoppler.ActivityLog`\n\n<!-- tabs-open -->","ref":"ExDoppler.ActivityLogs.html#get_activity_log/1"},{"type":"function","title":"🏷️ Params - ExDoppler.ActivityLogs.get_activity_log/1","doc":"* **id**: Unique identifier for the log object. (e.g `\"dmwk7ra70oem3xa\"`)","ref":"ExDoppler.ActivityLogs.html#get_activity_log/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.ActivityLogs.get_activity_log/1","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.ActivityLog{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.ActivityLogs.html#get_activity_log/1-returns"},{"type":"function","title":"💻 Examples - ExDoppler.ActivityLogs.get_activity_log/1","doc":"iex> alias ExDoppler.ActivityLogs\n    iex> alias ExDoppler.ActivityLog\n    iex> [%ActivityLog{id: id} | _ ] = ActivityLogs.list_activity_logs!(page: 1, per_page: 20)\n    iex> {:ok, _log = %ActivityLog{}} = ActivityLogs.get_activity_log(id)","ref":"ExDoppler.ActivityLogs.html#get_activity_log/1-examples"},{"type":"function","title":"📖 Resources - ExDoppler.ActivityLogs.get_activity_log/1","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/activity_logs-retrieve){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.ActivityLogs.html#get_activity_log/1-resources"},{"type":"function","title":"ExDoppler.ActivityLogs.get_activity_log!/1","doc":"Same as `get_activity_log/1` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.ActivityLogs.html#get_activity_log!/1"},{"type":"function","title":"ExDoppler.ActivityLogs.list_activity_logs/1","doc":"Lists `ExDoppler.ActivityLog` using pagination.\n\n<!-- tabs-open -->","ref":"ExDoppler.ActivityLogs.html#list_activity_logs/1"},{"type":"function","title":"🏷️ Params - ExDoppler.ActivityLogs.list_activity_logs/1","doc":"* **opts**: Optional modifications to the list call\n    * **page** - which page to list (starts at 1) (e.g `page: 2`). Default: `1`\n    * **per_page** - the number of `ExDoppler.ActivityLog` to return for this page (e.g `per_page: 50`). Default: `20`","ref":"ExDoppler.ActivityLogs.html#list_activity_logs/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.ActivityLogs.list_activity_logs/1","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, [%ExDoppler.ActivityLog{...} ...]}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.ActivityLogs.html#list_activity_logs/1-returns"},{"type":"function","title":"💻 Examples - ExDoppler.ActivityLogs.list_activity_logs/1","doc":"iex> alias ExDoppler.ActivityLogs\n    iex> {:ok, _logs} = ActivityLogs.list_activity_logs(page: 1, per_page: 20)","ref":"ExDoppler.ActivityLogs.html#list_activity_logs/1-examples"},{"type":"function","title":"📖 Resources - ExDoppler.ActivityLogs.list_activity_logs/1","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/activity_logs-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.ActivityLogs.html#list_activity_logs/1-resources"},{"type":"function","title":"ExDoppler.ActivityLogs.list_activity_logs!/1","doc":"Same as `list_activity_logs/1` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.ActivityLogs.html#list_activity_logs!/1"},{"type":"module","title":"ExDoppler.Auths","doc":"Module for interacting with `ExDoppler.TokenInfo` and `ExDoppler.ODICToken`\n\n<!-- tabs-open -->","ref":"ExDoppler.Auths.html"},{"type":"module","title":"📖 Resources - ExDoppler.Auths","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/service-account-identities){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/auth-me){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Auths.html#module-resources"},{"type":"function","title":"ExDoppler.Auths.me/0","doc":"Get information about the token in use.\n\n<!-- tabs-open -->","ref":"ExDoppler.Auths.html#me/0"},{"type":"function","title":"⤵️ Returns - ExDoppler.Auths.me/0","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.TokenInfo{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Auths.html#me/0-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Auths.me/0","doc":"iex> alias ExDoppler.TokenInfo\n    iex> alias ExDoppler.Auths\n    iex> {:ok, _token_info = %TokenInfo{}} = Auths.me()","ref":"ExDoppler.Auths.html#me/0-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Auths.me/0","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/auth-me){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Auths.html#me/0-resources"},{"type":"function","title":"ExDoppler.Auths.me!/0","doc":"Same as `me/0` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Auths.html#me!/0"},{"type":"function","title":"ExDoppler.Auths.odic/2","doc":"Authenticate via a Service Account Identity with OIDC. Returns a short-lived API token.\n\n<!-- tabs-open -->","ref":"ExDoppler.Auths.html#odic/2"},{"type":"function","title":"🏷️ Params - ExDoppler.Auths.odic/2","doc":"* **token**: the OIDC token string from your OIDC provider (likely CI)\n  * **identity**: Identity ID from the Doppler Dashboard","ref":"ExDoppler.Auths.html#odic/2-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Auths.odic/2","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.ODICToken{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Auths.html#odic/2-returns"},{"type":"function","title":"📖 Resources - ExDoppler.Auths.odic/2","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/auth-oidc){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Auths.html#odic/2-resources"},{"type":"function","title":"ExDoppler.Auths.odic!/2","doc":"Same as `odic/2` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Auths.html#odic!/2"},{"type":"function","title":"ExDoppler.Auths.revoke_auth_token/1","doc":"Revoke an auth token\n\n<!-- tabs-open -->","ref":"ExDoppler.Auths.html#revoke_auth_token/1"},{"type":"function","title":"🏷️ Params - ExDoppler.Auths.revoke_auth_token/1","doc":"* **token_to_revoke**: the auth token to revoke (e.g `\"auth-2342-asdf\"`)","ref":"ExDoppler.Auths.html#revoke_auth_token/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Auths.revoke_auth_token/1","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, {:success, true}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Auths.html#revoke_auth_token/1-returns"},{"type":"function","title":"📖 Resources - ExDoppler.Auths.revoke_auth_token/1","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/auth-revoke){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Auths.html#revoke_auth_token/1-resources"},{"type":"function","title":"ExDoppler.Auths.revoke_auth_token!/1","doc":"Same as `revoke_auth_token/1` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Auths.html#revoke_auth_token!/1"},{"type":"module","title":"ExDoppler.ConfigLogs","doc":"Module for interacting with `ExDoppler.ConfigLog`\n\n<!-- tabs-open -->","ref":"ExDoppler.ConfigLogs.html"},{"type":"module","title":"📖 Resources - ExDoppler.ConfigLogs","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/workplace-logs#config-logs){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/config_logs-object){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.ConfigLogs.html#module-resources"},{"type":"function","title":"ExDoppler.ConfigLogs.get_config_log/2","doc":"Retrieves a `ExDoppler.ConfigLog`, given a config and log id\n\n<!-- tabs-open -->","ref":"ExDoppler.ConfigLogs.html#get_config_log/2"},{"type":"function","title":"🏷️ Params - ExDoppler.ConfigLogs.get_config_log/2","doc":"* **config**: The relevant `ExDoppler.Config` (e.g `%Config{project: \"example-project\", name: \"dev\"}`)\n  * **log_id**: Unique identifier for the log object.","ref":"ExDoppler.ConfigLogs.html#get_config_log/2-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.ConfigLogs.get_config_log/2","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.ConfigLog{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.ConfigLogs.html#get_config_log/2-returns"},{"type":"function","title":"💻 Examples - ExDoppler.ConfigLogs.get_config_log/2","doc":"iex> alias ExDoppler.ConfigLogs\n    iex> alias ExDoppler.Configs\n    iex> alias ExDoppler.Projects\n    iex> [project | _] = Projects.list_projects!()\n    iex> [config | _] = Configs.list_configs!(project)\n    iex> _config_log = ConfigLogs.get_config_log(config, \"Ul8KeqJzKK3n7OadwqX5RZW2\")","ref":"ExDoppler.ConfigLogs.html#get_config_log/2-examples"},{"type":"function","title":"📖 Resources - ExDoppler.ConfigLogs.get_config_log/2","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/config_logs-get){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.ConfigLogs.html#get_config_log/2-resources"},{"type":"function","title":"ExDoppler.ConfigLogs.get_config_log!/2","doc":"Same as `get_config_log/2` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.ConfigLogs.html#get_config_log!/2"},{"type":"function","title":"ExDoppler.ConfigLogs.list_config_logs/2","doc":"Lists `ExDoppler.ConfigLog` using pagination.\n\n<!-- tabs-open -->","ref":"ExDoppler.ConfigLogs.html#list_config_logs/2"},{"type":"function","title":"🏷️ Params - ExDoppler.ConfigLogs.list_config_logs/2","doc":"* **config**: The `ExDoppler.Config` for which you want the logs (e.g `%Config{project: \"example-project\", name: \"dev\"}`)\n  * **opts**: Optional modifications to the list call\n    * **page** - which page to list (starts at 1) (e.g `page: 2`). Default: `1`\n    * **per_page** - the number of `ExDoppler.ConfigLog` to return for this page (e.g `per_page: 50`). Default: `20`","ref":"ExDoppler.ConfigLogs.html#list_config_logs/2-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.ConfigLogs.list_config_logs/2","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, [%ExDoppler.ConfigLog{...}]}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.ConfigLogs.html#list_config_logs/2-returns"},{"type":"function","title":"💻 Examples - ExDoppler.ConfigLogs.list_config_logs/2","doc":"iex> alias ExDoppler.ConfigLogs\n    iex> alias ExDoppler.Configs\n    iex> alias ExDoppler.Projects\n    iex> [project | _] = Projects.list_projects!()\n    iex> [config | _] = Configs.list_configs!(project)\n    iex> _config_logs = ConfigLogs.list_config_logs!(config, page: 1, per_page: 20)","ref":"ExDoppler.ConfigLogs.html#list_config_logs/2-examples"},{"type":"function","title":"📖 Resources - ExDoppler.ConfigLogs.list_config_logs/2","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/config_logs-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.ConfigLogs.html#list_config_logs/2-resources"},{"type":"function","title":"ExDoppler.ConfigLogs.list_config_logs!/2","doc":"Same as `list_config_logs/2` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.ConfigLogs.html#list_config_logs!/2"},{"type":"function","title":"ExDoppler.ConfigLogs.rollback_config_log/1","doc":"Rolls back a `ExDoppler.ConfigLog`\n\n<!-- tabs-open -->","ref":"ExDoppler.ConfigLogs.html#rollback_config_log/1"},{"type":"function","title":"🏷️ Params - ExDoppler.ConfigLogs.rollback_config_log/1","doc":"* **config_log**: The `ExDoppler.ConfigLog` to roll back (e.g `%ConfigLog{project: \"example-project\", config: \"dev\", id: \"0000..\"}`)","ref":"ExDoppler.ConfigLogs.html#rollback_config_log/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.ConfigLogs.rollback_config_log/1","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.ConfigLog{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.ConfigLogs.html#rollback_config_log/1-returns"},{"type":"function","title":"💻 Examples - ExDoppler.ConfigLogs.rollback_config_log/1","doc":"iex> alias ExDoppler.ConfigLogs\n    iex> alias ExDoppler.ConfigLog\n    iex> _config_log = ConfigLogs.rollback_config_log!(%ConfigLog{project: \"example-project\", config: \"dev\", id: \"Ul8KeqJzKK3n7OadwqX5RZW2\" })","ref":"ExDoppler.ConfigLogs.html#rollback_config_log/1-examples"},{"type":"function","title":"📖 Resources - ExDoppler.ConfigLogs.rollback_config_log/1","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/config_logs-rollback){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.ConfigLogs.html#rollback_config_log/1-resources"},{"type":"function","title":"ExDoppler.ConfigLogs.rollback_config_log!/1","doc":"Same as `rollback_config_log/1` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.ConfigLogs.html#rollback_config_log!/1"},{"type":"module","title":"ExDoppler.Configs","doc":"Module for interacting with `ExDoppler.Config`\n\n<!-- tabs-open -->","ref":"ExDoppler.Configs.html"},{"type":"module","title":"📖 Resources - ExDoppler.Configs","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/root-configs){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/configs-object){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Configs.html#module-resources"},{"type":"function","title":"ExDoppler.Configs.clone_config/3","doc":"Clones a `ExDoppler.Config` to a new Config\n\n<!-- tabs-open -->","ref":"ExDoppler.Configs.html#clone_config/3"},{"type":"function","title":"🏷️ Params - ExDoppler.Configs.clone_config/3","doc":"* **project_name**: The relevant project name (e.g `\"example-project\"`)\n  * **source_config**: The config to clone (e.g `\"prd_aws\"`)\n  * **new_config_name**: The config name to clone (e.g `\"prd_aws2\"`)","ref":"ExDoppler.Configs.html#clone_config/3-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Configs.clone_config/3","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.Config{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Configs.html#clone_config/3-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Configs.clone_config/3","doc":"iex> alias ExDoppler.Configs\n    iex> _ = Configs.delete_config!(\"example-project\", \"dev_doc\")\n    iex> _ = Configs.delete_config!(\"example-project\", \"dev_doc2\")\n    iex> {:ok, _config} = Configs.create_config(\"example-project\", \"dev\", \"dev_doc\")\n    iex> {:ok, _config} = Configs.clone_config(\"example-project\", \"dev_doc\", \"dev_doc2\")\n    iex> :ok = Configs.delete_config!(\"example-project\", \"dev_doc\")\n    iex> :ok = Configs.delete_config!(\"example-project\", \"dev_doc2\")","ref":"ExDoppler.Configs.html#clone_config/3-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Configs.clone_config/3","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/configs-clone){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Configs.html#clone_config/3-resources"},{"type":"function","title":"ExDoppler.Configs.clone_config!/3","doc":"Same as `clone_config/3` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Configs.html#clone_config!/3"},{"type":"function","title":"ExDoppler.Configs.create_config/3","doc":"Creates a new `ExDoppler.Config`\n\n<!-- tabs-open -->","ref":"ExDoppler.Configs.html#create_config/3"},{"type":"function","title":"🏷️ Params - ExDoppler.Configs.create_config/3","doc":"* **project_name**: The relevant project name (e.g `\"example-project\"`)\n  * **environment_id**: The relevant environment id (e.g `\"prd\"`)\n  * **config_name**: The config name to make (e.g `\"prd_aws\"`)","ref":"ExDoppler.Configs.html#create_config/3-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Configs.create_config/3","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.Config{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Configs.html#create_config/3-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Configs.create_config/3","doc":"iex> alias ExDoppler.Configs\n    iex> _ = Configs.delete_config!(\"example-project\", \"dev_doc\")\n    iex> {:ok, _config} = Configs.create_config(\"example-project\", \"dev\", \"dev_doc\")\n    iex> {:ok, _config} = Configs.get_config(\"example-project\", \"dev_doc\")\n    iex> {:ok, _} = Configs.delete_config(\"example-project\", \"dev_doc\")","ref":"ExDoppler.Configs.html#create_config/3-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Configs.create_config/3","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/configs-create){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Configs.html#create_config/3-resources"},{"type":"function","title":"ExDoppler.Configs.create_config!/3","doc":"Same as `create_config/3` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Configs.html#create_config!/3"},{"type":"function","title":"ExDoppler.Configs.delete_config/2","doc":"Deletes a `ExDoppler.Config`\n\n<!-- tabs-open -->","ref":"ExDoppler.Configs.html#delete_config/2"},{"type":"function","title":"🏷️ Params - ExDoppler.Configs.delete_config/2","doc":"* **project_name**: The relevant project name (e.g `\"example-project\"`)\n  * **config_name**: The config to delete (e.g `\"prd_aws\"`)","ref":"ExDoppler.Configs.html#delete_config/2-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Configs.delete_config/2","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, {:success, true}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Configs.html#delete_config/2-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Configs.delete_config/2","doc":"iex> alias ExDoppler.Configs\n    iex> alias ExDoppler.Config\n    iex> _ = Configs.delete_config!(\"example-project\", \"dev_doc\")\n    iex> {:ok, _config} = Configs.create_config(\"example-project\", \"dev\", \"dev_doc\")\n    iex> {:ok, {:success, true}} = Configs.delete_config(\"example-project\", \"dev_doc\")","ref":"ExDoppler.Configs.html#delete_config/2-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Configs.delete_config/2","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/configs-delete){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Configs.html#delete_config/2-resources"},{"type":"function","title":"ExDoppler.Configs.delete_config!/2","doc":"Same as `delete_config/2` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Configs.html#delete_config!/2"},{"type":"function","title":"ExDoppler.Configs.get_config/2","doc":"Retrieves a `ExDoppler.Config`\n\n<!-- tabs-open -->","ref":"ExDoppler.Configs.html#get_config/2"},{"type":"function","title":"🏷️ Params - ExDoppler.Configs.get_config/2","doc":"* **project_name**: The relevant project name (e.g `\"example-project\"`)\n  * **config_name**: The config name to get (e.g `\"dev_personal\"`)","ref":"ExDoppler.Configs.html#get_config/2-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Configs.get_config/2","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.Config{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Configs.html#get_config/2-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Configs.get_config/2","doc":"iex> alias ExDoppler.Configs\n    iex> {:ok, _config} = Configs.get_config(\"example-project\", \"dev\")","ref":"ExDoppler.Configs.html#get_config/2-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Configs.get_config/2","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/configs-get){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Configs.html#get_config/2-resources"},{"type":"function","title":"ExDoppler.Configs.get_config!/2","doc":"Same as `get_config/2` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Configs.html#get_config!/2"},{"type":"function","title":"ExDoppler.Configs.list_configs/2","doc":"Lists `ExDoppler.Config` using pagination.\n\n<!-- tabs-open -->","ref":"ExDoppler.Configs.html#list_configs/2"},{"type":"function","title":"🏷️ Params - ExDoppler.Configs.list_configs/2","doc":"* **project**: The `ExDoppler.Project` for which you want the configs (e.g `%Project{name: \"example-project\"}`)\n  * **opts**: Optional modifications to the list call\n    * **page** - which page to list (starts at 1) (e.g `page: 2`). Default: `1`\n    * **per_page** - the number of `ExDoppler.Config` to return for this page (e.g `per_page: 50`). Default: `20`","ref":"ExDoppler.Configs.html#list_configs/2-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Configs.list_configs/2","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, [%ExDoppler.Config{...}]}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Configs.html#list_configs/2-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Configs.list_configs/2","doc":"iex> alias ExDoppler.Configs\n    iex> alias ExDoppler.Projects\n    iex> [project | _] = Projects.list_projects!()\n    iex> {:ok, _configs} = Configs.list_configs(project, page: 1, per_page: 20)","ref":"ExDoppler.Configs.html#list_configs/2-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Configs.list_configs/2","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/configs-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Configs.html#list_configs/2-resources"},{"type":"function","title":"ExDoppler.Configs.list_configs!/2","doc":"Same as `list_configs/2` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Configs.html#list_configs!/2"},{"type":"function","title":"ExDoppler.Configs.list_trusted_ips/2","doc":"","ref":"ExDoppler.Configs.html#list_trusted_ips/2"},{"type":"function","title":"ExDoppler.Configs.lock_config/2","doc":"Locks a `ExDoppler.Config` (no modifications allowed)\n\n<!-- tabs-open -->","ref":"ExDoppler.Configs.html#lock_config/2"},{"type":"function","title":"🏷️ Params - ExDoppler.Configs.lock_config/2","doc":"* **project_name**: The relevant project name (e.g `\"example-project\"`)\n  * **config_name**: The config to lock (e.g `\"prd_aws\"`)","ref":"ExDoppler.Configs.html#lock_config/2-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Configs.lock_config/2","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.Config{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Configs.html#lock_config/2-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Configs.lock_config/2","doc":"iex> alias ExDoppler.Configs\n    iex> alias ExDoppler.Config\n    iex> _ = Configs.delete_config!(\"example-project\", \"dev_doc\")\n    iex> {:ok, _config} = Configs.create_config(\"example-project\", \"dev\", \"dev_doc\")\n    iex> {:ok, %Config{locked: true}} = Configs.lock_config(\"example-project\", \"dev_doc\")\n    iex> {:ok, %Config{locked: false}} = Configs.unlock_config(\"example-project\", \"dev_doc\")\n    iex> :ok = Configs.delete_config!(\"example-project\", \"dev_doc\")","ref":"ExDoppler.Configs.html#lock_config/2-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Configs.lock_config/2","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/configs-lock){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Configs.html#lock_config/2-resources"},{"type":"function","title":"ExDoppler.Configs.lock_config!/2","doc":"Same as `lock_config/2` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Configs.html#lock_config!/2"},{"type":"function","title":"ExDoppler.Configs.rename_config/3","doc":"Renames a `ExDoppler.Config`\n\n<!-- tabs-open -->","ref":"ExDoppler.Configs.html#rename_config/3"},{"type":"function","title":"🏷️ Params - ExDoppler.Configs.rename_config/3","doc":"* **project_name**: The relevant project name (e.g `\"example-project\"`)\n  * **current_config_name**: The relevant environment id (e.g `\"prd_aws\"`)\n  * **new_config_name**: The new config name (e.g `\"prd_gcp\"`)","ref":"ExDoppler.Configs.html#rename_config/3-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Configs.rename_config/3","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.Config{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Configs.html#rename_config/3-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Configs.rename_config/3","doc":"iex> alias ExDoppler.Configs\n    iex> _ = Configs.delete_config!(\"example-project\", \"dev_doc\")\n    iex> _ = Configs.delete_config!(\"example-project\", \"dev_doc2\")\n    iex> {:ok, _config} = Configs.create_config(\"example-project\", \"dev\", \"dev_doc\")\n    iex> {:ok, _config} = Configs.rename_config(\"example-project\", \"dev_doc\", \"dev_doc2\")\n    iex> {:ok, _} = Configs.delete_config(\"example-project\", \"dev_doc2\")","ref":"ExDoppler.Configs.html#rename_config/3-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Configs.rename_config/3","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/configs-update){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Configs.html#rename_config/3-resources"},{"type":"function","title":"ExDoppler.Configs.rename_config!/3","doc":"Same as `rename_config/3` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Configs.html#rename_config!/3"},{"type":"function","title":"ExDoppler.Configs.set_config_inheritable/3","doc":"","ref":"ExDoppler.Configs.html#set_config_inheritable/3"},{"type":"function","title":"ExDoppler.Configs.set_config_inheritable!/3","doc":"Same as `set_config_inheritable/3` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Configs.html#set_config_inheritable!/3"},{"type":"function","title":"ExDoppler.Configs.unlock_config/2","doc":"Unlocks a `ExDoppler.Config` (modifications allowed)\n\n<!-- tabs-open -->","ref":"ExDoppler.Configs.html#unlock_config/2"},{"type":"function","title":"🏷️ Params - ExDoppler.Configs.unlock_config/2","doc":"* **project_name**: The relevant project name (e.g `\"example-project\"`)\n  * **config_name**: The config to unlock (e.g `\"prd_aws\"`)","ref":"ExDoppler.Configs.html#unlock_config/2-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Configs.unlock_config/2","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.Config{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Configs.html#unlock_config/2-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Configs.unlock_config/2","doc":"iex> alias ExDoppler.Configs\n    iex> alias ExDoppler.Config\n    iex> _ = Configs.delete_config!(\"example-project\", \"dev_doc\")\n    iex> {:ok, _config} = Configs.create_config(\"example-project\", \"dev\", \"dev_doc\")\n    iex> {:ok, %Config{locked: true}} = Configs.lock_config(\"example-project\", \"dev_doc\")\n    iex> {:ok, %Config{locked: false}} = Configs.unlock_config(\"example-project\", \"dev_doc\")\n    iex> :ok = Configs.delete_config!(\"example-project\", \"dev_doc\")","ref":"ExDoppler.Configs.html#unlock_config/2-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Configs.unlock_config/2","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/configs-unlock){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Configs.html#unlock_config/2-resources"},{"type":"function","title":"ExDoppler.Configs.unlock_config!/2","doc":"Same as `unlock_config/2` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Configs.html#unlock_config!/2"},{"type":"module","title":"ExDoppler.Environments","doc":"Module for interacting with `ExDoppler.Environment`\n\n<!-- tabs-open -->","ref":"ExDoppler.Environments.html"},{"type":"module","title":"📖 Resources - ExDoppler.Environments","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/create-project#environments){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/environments-object){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Environments.html#module-resources"},{"type":"function","title":"ExDoppler.Environments.create_environment/4","doc":"Creates a new `ExDoppler.Environment`\n\n<!-- tabs-open -->","ref":"ExDoppler.Environments.html#create_environment/4"},{"type":"function","title":"🏷️ Params - ExDoppler.Environments.create_environment/4","doc":"* **project_name**: The relevant project name (e.g `\"example-project\"`)\n  * **env_name**: A new environment's name (e.g `\"prd\"`)\n  * **env_slug**: A new environment's slug (e.g `\"prd\"`)\n  * **enable_personal_config**: Optional setting if this environment has personal configs (default: `false`)","ref":"ExDoppler.Environments.html#create_environment/4-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Environments.create_environment/4","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.Environment{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Environments.html#create_environment/4-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Environments.create_environment/4","doc":"iex> alias ExDoppler.Environments\n    iex> alias ExDoppler.Environment\n    iex> alias ExDoppler.Projects\n    iex> [project | _] = Projects.list_projects!()\n    iex> _ = Environments.delete_environment(%Environment{project: project.name, slug: \"envdoc\"})\n    iex> {:ok, env} = Environments.create_environment(project, \"envdoc\", \"envdoc\")\n    iex> :ok = Environments.delete_environment!(env)","ref":"ExDoppler.Environments.html#create_environment/4-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Environments.create_environment/4","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/environments-create){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Environments.html#create_environment/4-resources"},{"type":"function","title":"ExDoppler.Environments.create_environment!/4","doc":"Same as `create_environment/4` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Environments.html#create_environment!/4"},{"type":"function","title":"ExDoppler.Environments.delete_environment/1","doc":"Deletes a `ExDoppler.Environment`\n\n<!-- tabs-open -->","ref":"ExDoppler.Environments.html#delete_environment/1"},{"type":"function","title":"🏷️ Params - ExDoppler.Environments.delete_environment/1","doc":"* **environment**: The relevant environment (e.g `%Environment{project: \"example-project\", slug: \"dev\" ...}`)","ref":"ExDoppler.Environments.html#delete_environment/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Environments.delete_environment/1","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, {:success, true}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Environments.html#delete_environment/1-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Environments.delete_environment/1","doc":"iex> alias ExDoppler.Environments\n    iex> alias ExDoppler.Environment\n    iex> alias ExDoppler.Projects\n    iex> [project | _] = Projects.list_projects!()\n    iex> _ = Environments.delete_environment(%Environment{project: project.name, slug: \"envdoc\"})\n    iex> {:ok, env} = Environments.create_environment(project, \"envdoc\", \"envdoc\")\n    iex> {:ok, {:success, true}} = Environments.delete_environment(env)","ref":"ExDoppler.Environments.html#delete_environment/1-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Environments.delete_environment/1","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/environments-delete){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Environments.html#delete_environment/1-resources"},{"type":"function","title":"ExDoppler.Environments.delete_environment!/1","doc":"Same as `delete_environment/1` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Environments.html#delete_environment!/1"},{"type":"function","title":"ExDoppler.Environments.get_environment/2","doc":"Retrieves a `ExDoppler.Environment`\n\n<!-- tabs-open -->","ref":"ExDoppler.Environments.html#get_environment/2"},{"type":"function","title":"🏷️ Params - ExDoppler.Environments.get_environment/2","doc":"* **project_name**: The relevant project name (e.g `\"example-project\"`)\n  * **config_name**: The environment to get (e.g `\"dev\"`)","ref":"ExDoppler.Environments.html#get_environment/2-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Environments.get_environment/2","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.Environment{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Environments.html#get_environment/2-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Environments.get_environment/2","doc":"iex> alias ExDoppler.Environments\n    iex> alias ExDoppler.Projects\n    iex> [project | _] = Projects.list_projects!()\n    iex> {:ok, _env} = Environments.get_environment(project, \"dev\")","ref":"ExDoppler.Environments.html#get_environment/2-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Environments.get_environment/2","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/environments-get){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Environments.html#get_environment/2-resources"},{"type":"function","title":"ExDoppler.Environments.get_environment!/2","doc":"Same as `get_environment/2` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Environments.html#get_environment!/2"},{"type":"function","title":"ExDoppler.Environments.list_environments/2","doc":"Lists `ExDoppler.Environment` using pagination.\n\n<!-- tabs-open -->","ref":"ExDoppler.Environments.html#list_environments/2"},{"type":"function","title":"🏷️ Params - ExDoppler.Environments.list_environments/2","doc":"* **project**: The `ExDoppler.Project` for which you want the environments (e.g `%Project{name: \"example-project\"}`)\n  * **opts**: Optional modifications to the list call\n    * **page** - which page to list (starts at 1) (e.g `page: 2`). Default: `1`\n    * **per_page** - the number of `ExDoppler.Environment` to return for this page (e.g `per_page: 50`). Default: `20`","ref":"ExDoppler.Environments.html#list_environments/2-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Environments.list_environments/2","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, [%ExDoppler.Environment{...}]}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Environments.html#list_environments/2-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Environments.list_environments/2","doc":"iex> alias ExDoppler.Environments\n    iex> alias ExDoppler.Projects\n    iex> [project | _] = Projects.list_projects!()\n    iex> {:ok, _envs} = Environments.list_environments(project, page: 1, per_page: 20)","ref":"ExDoppler.Environments.html#list_environments/2-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Environments.list_environments/2","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/environments-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Environments.html#list_environments/2-resources"},{"type":"function","title":"ExDoppler.Environments.list_environments!/2","doc":"Same as `list_environments/2` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Environments.html#list_environments!/2"},{"type":"function","title":"ExDoppler.Environments.update_environment/2","doc":"Updates an `ExDoppler.Environment`, given a project name, a env slug and options detailing modifications\n\n<!-- tabs-open -->","ref":"ExDoppler.Environments.html#update_environment/2"},{"type":"function","title":"🏷️ Params - ExDoppler.Environments.update_environment/2","doc":"* **environment**: The relevant environment (e.g `%Environment{project: \"example-project\", slug: \"dev\" ...}`)\n  * **opts**: Optional modifications\n    * **name** - New name for this environment\n    * **slug** - New slug for this environment\n    * **personal_configs** - If set true, will enable personal configs","ref":"ExDoppler.Environments.html#update_environment/2-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Environments.update_environment/2","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.Environment{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Environments.html#update_environment/2-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Environments.update_environment/2","doc":"iex> alias ExDoppler.Environments\n    iex> alias ExDoppler.Environment\n    iex> alias ExDoppler.Projects\n    iex> [project | _] = Projects.list_projects!()\n    iex> _ = Environments.delete_environment(%Environment{project: project.name, slug: \"envdoc\"})\n    iex> _ = Environments.delete_environment(%Environment{project: project.name, slug: \"envdoc2\"})\n    iex> {:ok, env} = Environments.create_environment(project, \"envdoc\", \"envdoc\")\n    iex> {:ok, updated} = Environments.update_environment(env, name: \"envdoc2\", personal_configs: true)\n    iex> :ok = Environments.delete_environment!(updated)","ref":"ExDoppler.Environments.html#update_environment/2-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Environments.update_environment/2","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/environments-rename){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Environments.html#update_environment/2-resources"},{"type":"function","title":"ExDoppler.Environments.update_environment!/2","doc":"Same as `update_environment/2` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Environments.html#update_environment!/2"},{"type":"module","title":"ExDoppler.Integrations","doc":"Module for interacting with `ExDoppler.Integration`\n\n<!-- tabs-open -->","ref":"ExDoppler.Integrations.html"},{"type":"module","title":"📖 Resources - ExDoppler.Integrations","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/integrations){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/integrations-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Integrations.html#module-resources"},{"type":"function","title":"ExDoppler.Integrations.create_integration/3","doc":"Creates a new `ExDoppler.Integration`\n\n\n> #### Read the API docs! {: .warning}\n>\n> The `data` parameter is tailored toward each kind of `type`.\n\n<!-- tabs-open -->","ref":"ExDoppler.Integrations.html#create_integration/3"},{"type":"function","title":"🏷️ Params - ExDoppler.Integrations.create_integration/3","doc":"* **type**: Integration Type (e.g `\"aws_secrets_manager\"`)\n  * **name**: Integration Name (e.g `\"aws-secrets-integration\"`)\n  * **data**: A map containing fields that are specific to each integration (e.g `%{\"aws_assume_role_arn\" : \"arn...\"}`)","ref":"ExDoppler.Integrations.html#create_integration/3-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Integrations.create_integration/3","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.Integration{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Integrations.html#create_integration/3-returns"},{"type":"function","title":"📖 Resources - ExDoppler.Integrations.create_integration/3","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/integrations-create){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Integrations.html#create_integration/3-resources"},{"type":"function","title":"ExDoppler.Integrations.create_integration!/3","doc":"Same as `create_integration/3` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Integrations.html#create_integration!/3"},{"type":"function","title":"ExDoppler.Integrations.delete_integration/1","doc":"Deletes a `ExDoppler.Integration`\n\n<!-- tabs-open -->","ref":"ExDoppler.Integrations.html#delete_integration/1"},{"type":"function","title":"🏷️ Params - ExDoppler.Integrations.delete_integration/1","doc":"* **integration**: The relevant integration (e.g `%Integration{slug: \"e32d0dcd-c094-4606-aefa-c4127e2a1282\"... }`)","ref":"ExDoppler.Integrations.html#delete_integration/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Integrations.delete_integration/1","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, {:success, true}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Integrations.html#delete_integration/1-returns"},{"type":"function","title":"📖 Resources - ExDoppler.Integrations.delete_integration/1","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/integrations-delete){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Integrations.html#delete_integration/1-resources"},{"type":"function","title":"ExDoppler.Integrations.delete_integration!/1","doc":"Same as `delete_integration/1` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Integrations.html#delete_integration!/1"},{"type":"function","title":"ExDoppler.Integrations.get_integration/1","doc":"Retrieves a `ExDoppler.Integration`\n\n<!-- tabs-open -->","ref":"ExDoppler.Integrations.html#get_integration/1"},{"type":"function","title":"🏷️ Params - ExDoppler.Integrations.get_integration/1","doc":"* **integration_slug**: The relevant integration (e.g `\"gh-integration\"`)","ref":"ExDoppler.Integrations.html#get_integration/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Integrations.get_integration/1","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.Integration{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Integrations.html#get_integration/1-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Integrations.get_integration/1","doc":"iex> alias ExDoppler.Integrations\n    iex> [integration | _] = Integrations.list_integrations!()\n    iex> _integration = Integrations.get_integration(integration.slug)","ref":"ExDoppler.Integrations.html#get_integration/1-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Integrations.get_integration/1","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/integrations-get){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Integrations.html#get_integration/1-resources"},{"type":"function","title":"ExDoppler.Integrations.get_integration!/1","doc":"Same as `get_integration/1` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Integrations.html#get_integration!/1"},{"type":"function","title":"ExDoppler.Integrations.get_integration_options/1","doc":"Returns the data payload for the integration\n\n> #### Read the API docs! {: .warning}\n>\n> These options relate to the `data` payload inside each integration\n> Please use with care\n\n<!-- tabs-open -->","ref":"ExDoppler.Integrations.html#get_integration_options/1"},{"type":"function","title":"🏷️ Params - ExDoppler.Integrations.get_integration_options/1","doc":"* **integration_slug**: Unique identifier for the integration (e.g `\"00000000-0000-0000-0000-000000000000\"`)","ref":"ExDoppler.Integrations.html#get_integration_options/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Integrations.get_integration_options/1","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, options}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Integrations.html#get_integration_options/1-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Integrations.get_integration_options/1","doc":"iex> alias ExDoppler.Integrations\n    iex> [integration | _] = Integrations.list_integrations!()\n    iex> _integration = Integrations.get_integration_options(integration.slug)","ref":"ExDoppler.Integrations.html#get_integration_options/1-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Integrations.get_integration_options/1","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/get-options){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Integrations.html#get_integration_options/1-resources"},{"type":"function","title":"ExDoppler.Integrations.get_integration_options!/1","doc":"Same as `get_integration_options/1` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Integrations.html#get_integration_options!/1"},{"type":"function","title":"ExDoppler.Integrations.list_integrations/0","doc":"Lists `ExDoppler.Integration`\n\n<!-- tabs-open -->","ref":"ExDoppler.Integrations.html#list_integrations/0"},{"type":"function","title":"⤵️ Returns - ExDoppler.Integrations.list_integrations/0","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, [%ExDoppler.Integration{...}]}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Integrations.html#list_integrations/0-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Integrations.list_integrations/0","doc":"iex> alias ExDoppler.Integrations\n    iex> {:ok, _integrations} = Integrations.list_integrations()","ref":"ExDoppler.Integrations.html#list_integrations/0-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Integrations.list_integrations/0","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/integrations-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Integrations.html#list_integrations/0-resources"},{"type":"function","title":"ExDoppler.Integrations.list_integrations!/0","doc":"Same as `list_integrations/0` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Integrations.html#list_integrations!/0"},{"type":"function","title":"ExDoppler.Integrations.update_integration/3","doc":"Updates an `ExDoppler.Integration`\n\n> #### Read the API docs! {: .warning}\n>\n> The `data` parameter is tailored toward each kind of `type`.\n\n<!-- tabs-open -->","ref":"ExDoppler.Integrations.html#update_integration/3"},{"type":"function","title":"🏷️ Params - ExDoppler.Integrations.update_integration/3","doc":"* **Integration**: Integration to update (e.g `%Integration{slug: \"e32d0dcd-c094-4606-aefa-c4127e2a1282\"... }`)\n  * **data**: A map containing fields that are specific to each integration (e.g `%{\"aws_assume_role_arn\" : \"arn...\"}`)","ref":"ExDoppler.Integrations.html#update_integration/3-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Integrations.update_integration/3","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.Integration{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Integrations.html#update_integration/3-returns"},{"type":"function","title":"📖 Resources - ExDoppler.Integrations.update_integration/3","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/integrations-update){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Integrations.html#update_integration/3-resources"},{"type":"function","title":"ExDoppler.Integrations.update_integration!/3","doc":"Same as `update_integration/3` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Integrations.html#update_integration!/3"},{"type":"module","title":"ExDoppler.Invites","doc":"Module for interacting with `ExDoppler.Invite`\n\n<!-- tabs-open -->","ref":"ExDoppler.Invites.html"},{"type":"module","title":"📖 Resources - ExDoppler.Invites","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/workplace-team#send-invite){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/invites-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Invites.html#module-resources"},{"type":"function","title":"ExDoppler.Invites.list_invites/1","doc":"Lists `ExDoppler.Invite`\n\n<!-- tabs-open -->","ref":"ExDoppler.Invites.html#list_invites/1"},{"type":"function","title":"🏷️ Params - ExDoppler.Invites.list_invites/1","doc":"* **opts**: Optional modifications to the list call\n    * **page** - which page to list (starts at 1) (e.g `page: 2`). Default: `1`\n    * **per_page** - the number of `ExDoppler.Invite` to return for this page (e.g `per_page: 50`). Default: `20`","ref":"ExDoppler.Invites.html#list_invites/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Invites.list_invites/1","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, [%ExDoppler.Invite{...}]}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Invites.html#list_invites/1-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Invites.list_invites/1","doc":"iex> alias ExDoppler.Invites\n    iex> {:ok, _invites} = Invites.list_invites()","ref":"ExDoppler.Invites.html#list_invites/1-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Invites.list_invites/1","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/invites-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Invites.html#list_invites/1-resources"},{"type":"function","title":"ExDoppler.Invites.list_invites!/1","doc":"Same as `list_invites/1` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Invites.html#list_invites!/1"},{"type":"module","title":"ExDoppler.ProjectMembers","doc":"Module for interacting with `ExDoppler.ProjectMember`\n\n<!-- tabs-open -->","ref":"ExDoppler.ProjectMembers.html"},{"type":"module","title":"📖 Resources - ExDoppler.ProjectMembers","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/project-permissions#by-project){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/project_members-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.ProjectMembers.html#module-resources"},{"type":"function","title":"ExDoppler.ProjectMembers.get_project_member/3","doc":"Retrieves a `ExDoppler.ProjectMember`\n\n<!-- tabs-open -->","ref":"ExDoppler.ProjectMembers.html#get_project_member/3"},{"type":"function","title":"🏷️ Params - ExDoppler.ProjectMembers.get_project_member/3","doc":"* **project**: The `ExDoppler.Project` for which you want the environments (e.g `%Project{name: \"example-project\"}`)\n  * **member_type**: type of member (e.g `\"workplace_user\"`)\n  * **member_slug**: slug of member (e.g `\"e32d0dcd-c094-4606-aefa-c4127e2a1282\"`)","ref":"ExDoppler.ProjectMembers.html#get_project_member/3-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.ProjectMembers.get_project_member/3","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.ProjectMember{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.ProjectMembers.html#get_project_member/3-returns"},{"type":"function","title":"💻 Examples - ExDoppler.ProjectMembers.get_project_member/3","doc":"iex> alias ExDoppler.ProjectMembers\n    iex> alias ExDoppler.Projects\n    iex> [project | _]= Projects.list_projects!()\n    iex> {:ok, [member | _]} = ProjectMembers.list_project_members(project, page: 1, per_page: 20)\n    iex> {:ok, _member} = ProjectMembers.get_project_member(project,  member.type, member.slug)","ref":"ExDoppler.ProjectMembers.html#get_project_member/3-examples"},{"type":"function","title":"📖 Resources - ExDoppler.ProjectMembers.get_project_member/3","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/project_members-get){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.ProjectMembers.html#get_project_member/3-resources"},{"type":"function","title":"ExDoppler.ProjectMembers.get_project_member!/3","doc":"Same as `get_project_member/3` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.ProjectMembers.html#get_project_member!/3"},{"type":"function","title":"ExDoppler.ProjectMembers.list_project_members/2","doc":"Lists `ExDoppler.ProjectMember` using pagination\n\n<!-- tabs-open -->","ref":"ExDoppler.ProjectMembers.html#list_project_members/2"},{"type":"function","title":"🏷️ Params - ExDoppler.ProjectMembers.list_project_members/2","doc":"* **project**: The `ExDoppler.Project` for which you want the environments (e.g `%Project{name: \"example-project\"}`)\n  * **opts**: Optional modifications to the list call\n    * **page** - which page to list (starts at 1) (e.g `page: 2`). Default: `1`\n    * **per_page** - the number of `ExDoppler.ProjectMember` to return for this page (e.g `per_page: 50`). Default: `20`","ref":"ExDoppler.ProjectMembers.html#list_project_members/2-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.ProjectMembers.list_project_members/2","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, [%ExDoppler.ProjectMember{...}]}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.ProjectMembers.html#list_project_members/2-returns"},{"type":"function","title":"💻 Examples - ExDoppler.ProjectMembers.list_project_members/2","doc":"iex> alias ExDoppler.ProjectMembers\n    iex> alias ExDoppler.Projects\n    iex> [project | _]= Projects.list_projects!()\n    iex> {:ok, _members} = ProjectMembers.list_project_members(project, page: 1, per_page: 20)","ref":"ExDoppler.ProjectMembers.html#list_project_members/2-examples"},{"type":"function","title":"📖 Resources - ExDoppler.ProjectMembers.list_project_members/2","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/project_members-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.ProjectMembers.html#list_project_members/2-resources"},{"type":"function","title":"ExDoppler.ProjectMembers.list_project_members!/2","doc":"Same as `list_project_members/2` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.ProjectMembers.html#list_project_members!/2"},{"type":"module","title":"ExDoppler.ProjectRoles","doc":"Module for interacting with `ExDoppler.ProjectRole`\n\n<!-- tabs-open -->","ref":"ExDoppler.ProjectRoles.html"},{"type":"module","title":"📖 Resources - ExDoppler.ProjectRoles","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/project-permissions){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/project_roles-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.ProjectRoles.html#module-resources"},{"type":"function","title":"ExDoppler.ProjectRoles.create_project_role/2","doc":"Creates a new `ExDoppler.ProjectRole`, given a name and list of permissions\n\n<!-- tabs-open -->","ref":"ExDoppler.ProjectRoles.html#create_project_role/2"},{"type":"function","title":"🏷️ Params - ExDoppler.ProjectRoles.create_project_role/2","doc":"* **name**: Role name (e.g `\"viewer_but_different\"`)\n  * **permissions**: List of permissions given to the role. See [Doppler Docs](https://docs.doppler.com/reference/project_roles-create){:target=\"_blank\"}","ref":"ExDoppler.ProjectRoles.html#create_project_role/2-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.ProjectRoles.create_project_role/2","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.ProjectRole{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.ProjectRoles.html#create_project_role/2-returns"},{"type":"function","title":"📖 Resources - ExDoppler.ProjectRoles.create_project_role/2","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/project_roles-create){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.ProjectRoles.html#create_project_role/2-resources"},{"type":"function","title":"ExDoppler.ProjectRoles.create_project_role!/2","doc":"Same as `create_project_role/1` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.ProjectRoles.html#create_project_role!/2"},{"type":"function","title":"ExDoppler.ProjectRoles.get_project_role/1","doc":"Retrieves a `ExDoppler.ProjectRole`\n\n<!-- tabs-open -->","ref":"ExDoppler.ProjectRoles.html#get_project_role/1"},{"type":"function","title":"🏷️ Params - ExDoppler.ProjectRoles.get_project_role/1","doc":"* **identifier** - identifier for role -  e.g `\"collaborator\"` or `\"admin\"` or `\"viewer\"` or `\"no_access\"`","ref":"ExDoppler.ProjectRoles.html#get_project_role/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.ProjectRoles.get_project_role/1","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.ProjectRole{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.ProjectRoles.html#get_project_role/1-returns"},{"type":"function","title":"💻 Examples - ExDoppler.ProjectRoles.get_project_role/1","doc":"iex> alias ExDoppler.ProjectRoles\n    iex> {:ok, [role | _]}= ProjectRoles.list_project_roles()\n    iex> {:ok,  _role} = ProjectRoles.get_project_role(role.identifier)","ref":"ExDoppler.ProjectRoles.html#get_project_role/1-examples"},{"type":"function","title":"📖 Resources - ExDoppler.ProjectRoles.get_project_role/1","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/project_roles-get){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.ProjectRoles.html#get_project_role/1-resources"},{"type":"function","title":"ExDoppler.ProjectRoles.get_project_role!/1","doc":"Same as `get_project_role/1` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.ProjectRoles.html#get_project_role!/1"},{"type":"function","title":"ExDoppler.ProjectRoles.list_project_roles/0","doc":"Lists `ExDoppler.ProjectRole`\n\n<!-- tabs-open -->","ref":"ExDoppler.ProjectRoles.html#list_project_roles/0"},{"type":"function","title":"⤵️ Returns - ExDoppler.ProjectRoles.list_project_roles/0","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, [%ExDoppler.ProjectRole{...} ...]}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.ProjectRoles.html#list_project_roles/0-returns"},{"type":"function","title":"💻 Examples - ExDoppler.ProjectRoles.list_project_roles/0","doc":"iex> alias ExDoppler.ProjectRoles\n    iex> {:ok, _roles} = ProjectRoles.list_project_roles()","ref":"ExDoppler.ProjectRoles.html#list_project_roles/0-examples"},{"type":"function","title":"📖 Resources - ExDoppler.ProjectRoles.list_project_roles/0","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/project_roles-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.ProjectRoles.html#list_project_roles/0-resources"},{"type":"function","title":"ExDoppler.ProjectRoles.list_project_roles!/0","doc":"Same as `list_project_roles/1` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.ProjectRoles.html#list_project_roles!/0"},{"type":"module","title":"ExDoppler.Projects","doc":"Module for interacting with `ExDoppler.Project`\n\n<!-- tabs-open -->","ref":"ExDoppler.Projects.html"},{"type":"module","title":"📖 Resources - ExDoppler.Projects","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/create-project){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/projects-object){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Projects.html#module-resources"},{"type":"function","title":"ExDoppler.Projects.create_project/2","doc":"Creates a new `ExDoppler.Project`\n\n<!-- tabs-open -->","ref":"ExDoppler.Projects.html#create_project/2"},{"type":"function","title":"🏷️ Params - ExDoppler.Projects.create_project/2","doc":"* **project_name**: New Project Name (e.g `\"example-project\"`)\n  * **description**: Optional description (e.g `\"my awesome project\"`)","ref":"ExDoppler.Projects.html#create_project/2-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Projects.create_project/2","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.Project{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Projects.html#create_project/2-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Projects.create_project/2","doc":"iex> alias ExDoppler.Projects\n    iex> alias ExDoppler.Project\n    iex> _ = Projects.delete_project!(%Project{name: \"example-doc-project\"})\n    iex> {:ok, project} = Projects.create_project(\"example-doc-project\")\n    iex> :ok = Projects.delete_project!(project)","ref":"ExDoppler.Projects.html#create_project/2-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Projects.create_project/2","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/projects-create){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Projects.html#create_project/2-resources"},{"type":"function","title":"ExDoppler.Projects.create_project!/2","doc":"Same as `create_project/1` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Projects.html#create_project!/2"},{"type":"function","title":"ExDoppler.Projects.delete_project/1","doc":"Deletes a `ExDoppler.Project`\n\n<!-- tabs-open -->","ref":"ExDoppler.Projects.html#delete_project/1"},{"type":"function","title":"🏷️ Params - ExDoppler.Projects.delete_project/1","doc":"* **project**: The relevant project (e.g `%Project{name: \"example-project\" ...}`)","ref":"ExDoppler.Projects.html#delete_project/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Projects.delete_project/1","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, {:success, true}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Projects.html#delete_project/1-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Projects.delete_project/1","doc":"iex> alias ExDoppler.Projects\n    iex> alias ExDoppler.Project\n    iex> _ = Projects.delete_project!(%Project{name: \"example-doc-project\"})\n    iex> project = Projects.create_project!(\"example-doc-project\")\n    iex> {:ok, {:success, true}} = Projects.delete_project(project)","ref":"ExDoppler.Projects.html#delete_project/1-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Projects.delete_project/1","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/projects-delete){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Projects.html#delete_project/1-resources"},{"type":"function","title":"ExDoppler.Projects.delete_project!/1","doc":"Same as `delete_project/1` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Projects.html#delete_project!/1"},{"type":"function","title":"ExDoppler.Projects.get_project/1","doc":"Retrieves a `ExDoppler.Project`, given an identifier\n\n<!-- tabs-open -->","ref":"ExDoppler.Projects.html#get_project/1"},{"type":"function","title":"🏷️ Params - ExDoppler.Projects.get_project/1","doc":"* `identifier` - identifier for project (e.g `\"example-project\"`)","ref":"ExDoppler.Projects.html#get_project/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Projects.get_project/1","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.Project{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Projects.html#get_project/1-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Projects.get_project/1","doc":"iex> alias ExDoppler.Projects\n    iex> {:ok, _project} = Projects.get_project(\"example-project\")","ref":"ExDoppler.Projects.html#get_project/1-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Projects.get_project/1","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/projects-get){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Projects.html#get_project/1-resources"},{"type":"function","title":"ExDoppler.Projects.get_project!/1","doc":"Same as `get_project/1` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Projects.html#get_project!/1"},{"type":"function","title":"ExDoppler.Projects.list_project_permissions/0","doc":"Lists project permissions across all roles\n\n<!-- tabs-open -->","ref":"ExDoppler.Projects.html#list_project_permissions/0"},{"type":"function","title":"⤵️ Returns - ExDoppler.Projects.list_project_permissions/0","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, [\"perm1\" ...]}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Projects.html#list_project_permissions/0-returns"},{"type":"function","title":"📖 Resources - ExDoppler.Projects.list_project_permissions/0","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/project_roles-list_permissions){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Projects.html#list_project_permissions/0-resources"},{"type":"function","title":"ExDoppler.Projects.list_project_permissions!/0","doc":"Same as `list_project_permissions/0` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Projects.html#list_project_permissions!/0"},{"type":"function","title":"ExDoppler.Projects.list_projects/1","doc":"Lists `ExDoppler.Project` using pagination\n\n<!-- tabs-open -->","ref":"ExDoppler.Projects.html#list_projects/1"},{"type":"function","title":"🏷️ Params - ExDoppler.Projects.list_projects/1","doc":"* **opts**: Optional modifications to the list call\n    * **page** - which page to list (starts at 1) (e.g `page: 2`). Default: `1`\n    * **per_page** - the number of `ExDoppler.Project` to return for this page (e.g `per_page: 50`). Default: `20`","ref":"ExDoppler.Projects.html#list_projects/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Projects.list_projects/1","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, [%ExDoppler.Project{...} ...]}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Projects.html#list_projects/1-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Projects.list_projects/1","doc":"iex> alias ExDoppler.Projects\n    iex> {:ok, _projects} = Projects.list_projects(page: 1, per_page: 20)","ref":"ExDoppler.Projects.html#list_projects/1-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Projects.list_projects/1","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/projects-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Projects.html#list_projects/1-resources"},{"type":"function","title":"ExDoppler.Projects.list_projects!/1","doc":"Same as `list_projects/1` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Projects.html#list_projects!/1"},{"type":"function","title":"ExDoppler.Projects.update_project/2","doc":"Updates an `ExDoppler.Project`\n\n<!-- tabs-open -->","ref":"ExDoppler.Projects.html#update_project/2"},{"type":"function","title":"🏷️ Params - ExDoppler.Projects.update_project/2","doc":"* **project**: The relevant project (e.g `%Project{name: \"example-project\" ...}`)\n  * **opts**: Optional modifications\n    * **name** - New name for this project\n    * **description** - New description for this project","ref":"ExDoppler.Projects.html#update_project/2-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Projects.update_project/2","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.Project{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Projects.html#update_project/2-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Projects.update_project/2","doc":"iex> alias ExDoppler.Projects\n    iex> alias ExDoppler.Project\n    iex> _ = Projects.delete_project!(%Project{name: \"example-doc-project\"})\n    iex> project = Projects.create_project!(\"example-doc-project\")\n    iex> {:ok, project} = Projects.update_project(project, description: \"new description\")\n    iex> :ok = Projects.delete_project!(project)","ref":"ExDoppler.Projects.html#update_project/2-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Projects.update_project/2","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/projects-update){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Projects.html#update_project/2-resources"},{"type":"function","title":"ExDoppler.Projects.update_project!/2","doc":"Same as `update_project/1` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Projects.html#update_project!/2"},{"type":"module","title":"ExDoppler.SecretSyncs","doc":"Module for interacting with `ExDoppler.Sync`\n\n<!-- tabs-open -->","ref":"ExDoppler.SecretSyncs.html"},{"type":"module","title":"📖 Resources - ExDoppler.SecretSyncs","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/integrations){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/syncs-create){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.SecretSyncs.html#module-resources"},{"type":"function","title":"ExDoppler.SecretSyncs.create_secrets_sync/3","doc":"Creates a new `ExDoppler.Sync`\n\n> #### Read the API docs! {: .warning}\n>\n> The `data` payload differs with each integration.\n> Please use with care\n\n<!-- tabs-open -->","ref":"ExDoppler.SecretSyncs.html#create_secrets_sync/3"},{"type":"function","title":"🏷️ Params - ExDoppler.SecretSyncs.create_secrets_sync/3","doc":"* **config** - Config associated with the Sync (e.g `%Config{name: \"dev_personal\", project: \"example-project\" ...}`)\n * **integration** - Integration associated with the Sync (e.g `%Integration{slug: \"e32d0dcd-c094-4606-aefa-c4127e2a1282\" ...}`)\n * **data** - A map of data associated with the Sync; the fields will differ depending on the integration","ref":"ExDoppler.SecretSyncs.html#create_secrets_sync/3-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.SecretSyncs.create_secrets_sync/3","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.Sync{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.SecretSyncs.html#create_secrets_sync/3-returns"},{"type":"function","title":"💻 Examples - ExDoppler.SecretSyncs.create_secrets_sync/3","doc":"iex> alias ExDoppler.Config\n    iex> alias ExDoppler.Integrations\n    iex> alias ExDoppler.SecretSyncs\n    iex> [integration | _] = Integrations.list_integrations!()\n    iex> config = %Config{name: \"github\", project: \"example-project\"}\n    iex> if !Enum.empty?(integration.syncs), do: :ok = SecretSyncs.delete_secrets_sync!(config, hd(integration.syncs))\n    iex> {:ok, github_sync} = SecretSyncs.create_secrets_sync(config, integration, %{sync_target: \"repo\", repo_name: \"ex_doppler\"})\n    iex> {:ok, _secrets_sync} = SecretSyncs.get_secrets_sync(config, github_sync.slug)\n    iex> :ok = SecretSyncs.delete_secrets_sync!(config, github_sync)","ref":"ExDoppler.SecretSyncs.html#create_secrets_sync/3-examples"},{"type":"function","title":"📖 Resources - ExDoppler.SecretSyncs.create_secrets_sync/3","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/syncs-create){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.SecretSyncs.html#create_secrets_sync/3-resources"},{"type":"function","title":"ExDoppler.SecretSyncs.create_secrets_sync!/3","doc":"Same as `create_secrets_sync/3` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.SecretSyncs.html#create_secrets_sync!/3"},{"type":"function","title":"ExDoppler.SecretSyncs.delete_secrets_sync/3","doc":"Deletes a `ExDoppler.Sync`\n\n<!-- tabs-open -->","ref":"ExDoppler.SecretSyncs.html#delete_secrets_sync/3"},{"type":"function","title":"🏷️ Params - ExDoppler.SecretSyncs.delete_secrets_sync/3","doc":"* **config** - Config associated with the Sync (e.g `%Config{name: \"dev_personal\", project: \"example-project\" ...}`)\n * **sync** - Sync to delete (e.g `%Sync{slug: \"e32d0dcd-c094-4606-aefa-c4127e2a1282\" ...}`)\n * **delete_from_target** - Whether or not to delete the synced data from the target integration. Defaults to `true`","ref":"ExDoppler.SecretSyncs.html#delete_secrets_sync/3-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.SecretSyncs.delete_secrets_sync/3","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, {:success, true}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.SecretSyncs.html#delete_secrets_sync/3-returns"},{"type":"function","title":"💻 Examples - ExDoppler.SecretSyncs.delete_secrets_sync/3","doc":"iex> alias ExDoppler.Config\n    iex> alias ExDoppler.Integrations\n    iex> alias ExDoppler.SecretSyncs\n    iex> [integration | _] = Integrations.list_integrations!()\n    iex> config = %Config{name: \"github\", project: \"example-project\"}\n    iex> if !Enum.empty?(integration.syncs), do: :ok = SecretSyncs.delete_secrets_sync!(config, hd(integration.syncs))\n    iex> {:ok, github_sync} = SecretSyncs.create_secrets_sync(config, integration, %{sync_target: \"repo\", repo_name: \"ex_doppler\"})\n    iex> {:ok, _secrets_sync} = SecretSyncs.get_secrets_sync(config, github_sync.slug)\n    iex> :ok = SecretSyncs.delete_secrets_sync!(config, github_sync)","ref":"ExDoppler.SecretSyncs.html#delete_secrets_sync/3-examples"},{"type":"function","title":"📖 Resources - ExDoppler.SecretSyncs.delete_secrets_sync/3","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/syncs-delete){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.SecretSyncs.html#delete_secrets_sync/3-resources"},{"type":"function","title":"ExDoppler.SecretSyncs.delete_secrets_sync!/3","doc":"Same as `delete_secrets_sync/3` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.SecretSyncs.html#delete_secrets_sync!/3"},{"type":"function","title":"ExDoppler.SecretSyncs.get_secrets_sync/2","doc":"Retrieves a `ExDoppler.Sync`\n\n<!-- tabs-open -->","ref":"ExDoppler.SecretSyncs.html#get_secrets_sync/2"},{"type":"function","title":"🏷️ Params - ExDoppler.SecretSyncs.get_secrets_sync/2","doc":"* **config** - Config to get secrets from (e.g `%Config{name: \"dev_personal\", project: \"example-project\" ...}`)\n * **sync_slug** - Unique ID for the Sync","ref":"ExDoppler.SecretSyncs.html#get_secrets_sync/2-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.SecretSyncs.get_secrets_sync/2","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.Sync{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.SecretSyncs.html#get_secrets_sync/2-returns"},{"type":"function","title":"💻 Examples - ExDoppler.SecretSyncs.get_secrets_sync/2","doc":"iex> alias ExDoppler.Config\n    iex> alias ExDoppler.Integrations\n    iex> alias ExDoppler.SecretSyncs\n    iex> [integration | _] = Integrations.list_integrations!()\n    iex> config = %Config{name: \"github\", project: \"example-project\"}\n    iex> if !Enum.empty?(integration.syncs), do: :ok = SecretSyncs.delete_secrets_sync!(config, hd(integration.syncs))\n    iex> {:ok, github_sync} = SecretSyncs.create_secrets_sync(config, integration, %{sync_target: \"repo\", repo_name: \"ex_doppler\"})\n    iex> {:ok, _secrets_sync} = SecretSyncs.get_secrets_sync(config, github_sync.slug)\n    iex> :ok = SecretSyncs.delete_secrets_sync!(config, github_sync)","ref":"ExDoppler.SecretSyncs.html#get_secrets_sync/2-examples"},{"type":"function","title":"📖 Resources - ExDoppler.SecretSyncs.get_secrets_sync/2","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/syncs-get){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.SecretSyncs.html#get_secrets_sync/2-resources"},{"type":"function","title":"ExDoppler.SecretSyncs.get_secrets_sync!/2","doc":"Same as `get_secrets_sync/2` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.SecretSyncs.html#get_secrets_sync!/2"},{"type":"module","title":"ExDoppler.Secrets","doc":"Module for interacting with `ExDoppler.Secret`\n\n<!-- tabs-open -->","ref":"ExDoppler.Secrets.html"},{"type":"module","title":"📖 Resources - ExDoppler.Secrets","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/secrets){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/secrets-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Secrets.html#module-resources"},{"type":"function","title":"ExDoppler.Secrets.create_secret/4","doc":"Creates a new `ExDoppler.Secret`\n\n<!-- tabs-open -->","ref":"ExDoppler.Secrets.html#create_secret/4"},{"type":"function","title":"🏷️ Params - ExDoppler.Secrets.create_secret/4","doc":"* **config** - Config to get secrets from (e.g `%Config{name: \"dev_personal\", project: \"example-project\" ...}`)\n * **new_secret_name** - Name of this new secret\n * **value** - Value of this new secret\n * **opts**: Optional modifications\n    * **visibility** - how the secret should appear - `:masked`, `:unmasked`, or `:restricted`. Default: `:masked`","ref":"ExDoppler.Secrets.html#create_secret/4-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Secrets.create_secret/4","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.Secret{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Secrets.html#create_secret/4-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Secrets.create_secret/4","doc":"iex> alias ExDoppler.Config\n    iex> alias ExDoppler.Secrets\n    iex> _ = Secrets.delete_secret!(%Config{name: \"dev_personal\", project: \"example-project\"}, \"DOC_URL\")\n    iex> {:ok, _secret} = Secrets.create_secret(%Config{name: \"dev_personal\", project: \"example-project\"}, \"DOC_URL\", \"example.com\")\n    iex> :ok = Secrets.delete_secret!(%Config{name: \"dev_personal\", project: \"example-project\"}, \"DOC_URL\")","ref":"ExDoppler.Secrets.html#create_secret/4-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Secrets.create_secret/4","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/secrets-update){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Secrets.html#create_secret/4-resources"},{"type":"function","title":"ExDoppler.Secrets.create_secret!/4","doc":"Same as `create_secret/4` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Secrets.html#create_secret!/4"},{"type":"function","title":"ExDoppler.Secrets.delete_secret/2","doc":"Deletes a `ExDoppler.Secret`\n\n<!-- tabs-open -->","ref":"ExDoppler.Secrets.html#delete_secret/2"},{"type":"function","title":"🏷️ Params - ExDoppler.Secrets.delete_secret/2","doc":"* **config** - Config to get secrets from (e.g `%Config{name: \"dev_personal\", project: \"example-project\" ...}`)\n * **secret_name** - Name of secret to delete","ref":"ExDoppler.Secrets.html#delete_secret/2-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Secrets.delete_secret/2","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, {:success, true}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Secrets.html#delete_secret/2-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Secrets.delete_secret/2","doc":"iex> alias ExDoppler.Config\n    iex> alias ExDoppler.Secrets\n    iex> _ = Secrets.delete_secret!(%Config{name: \"dev_personal\", project: \"example-project\"}, \"DOC_URL\")\n    iex> {:ok, _secret} = Secrets.create_secret(%Config{name: \"dev_personal\", project: \"example-project\"}, \"DOC_URL\", \"example.com\")\n    iex> {:ok, {:success, true}} = Secrets.delete_secret(%Config{name: \"dev_personal\", project: \"example-project\"}, \"DOC_URL\")","ref":"ExDoppler.Secrets.html#delete_secret/2-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Secrets.delete_secret/2","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/secrets-delete){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Secrets.html#delete_secret/2-resources"},{"type":"function","title":"ExDoppler.Secrets.delete_secret!/2","doc":"Same as `delete_secret/2` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Secrets.html#delete_secret!/2"},{"type":"function","title":"ExDoppler.Secrets.download/2","doc":"Retrieves multiple `ExDoppler.Secret` and responds in a format ready to put into a file\n\n<!-- tabs-open -->","ref":"ExDoppler.Secrets.html#download/2"},{"type":"function","title":"🏷️ Params - ExDoppler.Secrets.download/2","doc":"* **config** - Config to get secrets from (e.g `%Config{name: \"dev_personal\", project: \"example-project\" ...}`)\n * **opts**: Optional modifications to the download call\n    * **include_dynamic_secrets** - whether to include dynamic secrets. Default: `false`\n    * **dynamic_secrets_ttl_sec** - The number of seconds until dynamic leases expire. Must be used with include_dynamic_secrets. Defaults to 1800 (30 minutes). Default: `nil`\n    * **format** - File format to use. (e.g `\"dotnet-json\"`, `\"env\"`, `\"yaml\"`, `\"docker\"`, `\"env-no-quotes\"`) Default: `json`\n    * **name_transformer** - Transform secret names to a different case (e.g `\"camel\"`, `\"upper-camel\"`, `\"lower-snake\"`, `\"tf-var\"`, `\"dotnet\"`, `\"dotnet-env\"`, `\"lower-kebab\"`). Default: `nil`\n    * **secrets** - Comma-delimited list of secrets to include in the download. Defaults to all secrets if left unspecified.","ref":"ExDoppler.Secrets.html#download/2-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Secrets.download/2","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, requested_body}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Secrets.html#download/2-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Secrets.download/2","doc":"iex> alias ExDoppler.Config\n    iex> alias ExDoppler.Secrets\n    iex> {:ok, _formatted_body} = Secrets.download(%Config{name: \"dev_personal\", project: \"example-project\"}, format: :env, name_transformer: \"lower-snake\")","ref":"ExDoppler.Secrets.html#download/2-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Secrets.download/2","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/secrets-download){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Secrets.html#download/2-resources"},{"type":"function","title":"ExDoppler.Secrets.download!/2","doc":"Same as `download/2` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Secrets.html#download!/2"},{"type":"function","title":"ExDoppler.Secrets.get_secret/2","doc":"Retrieves a `ExDoppler.Secret`\n\n<!-- tabs-open -->","ref":"ExDoppler.Secrets.html#get_secret/2"},{"type":"function","title":"🏷️ Params - ExDoppler.Secrets.get_secret/2","doc":"* **config** - Config to get secrets from (e.g `%Config{name: \"dev_personal\", project: \"example-project\" ...}`)\n * **secret_name** - Name of the secret to get (e.g `\"API_KEY\"`)","ref":"ExDoppler.Secrets.html#get_secret/2-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Secrets.get_secret/2","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.Secret{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Secrets.html#get_secret/2-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Secrets.get_secret/2","doc":"iex> alias ExDoppler.Config\n    iex> alias ExDoppler.Secrets\n    iex> {:ok, _secret} = Secrets.get_secret(%Config{name: \"dev_personal\", project: \"example-project\"}, \"DB_URL\")","ref":"ExDoppler.Secrets.html#get_secret/2-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Secrets.get_secret/2","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/secrets-get){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Secrets.html#get_secret/2-resources"},{"type":"function","title":"ExDoppler.Secrets.get_secret!/2","doc":"Same as `get_secret/2` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Secrets.html#get_secret!/2"},{"type":"function","title":"ExDoppler.Secrets.list_secret_names/2","doc":"Lists the names of `ExDoppler.Secret`\n\n<!-- tabs-open -->","ref":"ExDoppler.Secrets.html#list_secret_names/2"},{"type":"function","title":"🏷️ Params - ExDoppler.Secrets.list_secret_names/2","doc":"* **config** - Config to get secrets from (e.g `%Config{name: \"dev_personal\", project: \"example-project\" ...}`)\n * **opts**: Optional modifications to the list call\n    * **include_dynamic_secrets** - whether to include dynamic secrets. Default: `false`\n    * **include_managed_secrets** - whether to include managed secrets. Default: `true`","ref":"ExDoppler.Secrets.html#list_secret_names/2-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Secrets.list_secret_names/2","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, names}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Secrets.html#list_secret_names/2-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Secrets.list_secret_names/2","doc":"iex> alias ExDoppler.Config\n    iex> alias ExDoppler.Secrets\n    iex> {:ok, _names} = Secrets.list_secret_names(%Config{name: \"dev_personal\", project: \"example-project\"})","ref":"ExDoppler.Secrets.html#list_secret_names/2-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Secrets.list_secret_names/2","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/secrets-names){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Secrets.html#list_secret_names/2-resources"},{"type":"function","title":"ExDoppler.Secrets.list_secret_names!/2","doc":"Same as `list_secret_names/2` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Secrets.html#list_secret_names!/2"},{"type":"function","title":"ExDoppler.Secrets.list_secrets/2","doc":"Lists `ExDoppler.Secret`\n\n<!-- tabs-open -->","ref":"ExDoppler.Secrets.html#list_secrets/2"},{"type":"function","title":"🏷️ Params - ExDoppler.Secrets.list_secrets/2","doc":"* **config**: Config to get secrets from (e.g `%Config{name: \"dev_personal\", project: \"example-project\" ...}`)\n  * **opts**: Optional modifications to the list call\n    * **include_dynamic_secrets** - whether to include dynamic secrets. Default: `false`\n    * **include_managed_secrets** - whether to include dynamic secrets. Default: `true`\n    * **secrets** - A comma-separated list of secrets to include in the response. Default: `nil`","ref":"ExDoppler.Secrets.html#list_secrets/2-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Secrets.list_secrets/2","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, [%ExDoppler.Secret{...} ...]}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Secrets.html#list_secrets/2-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Secrets.list_secrets/2","doc":"iex> alias ExDoppler.Configs\n    iex> alias ExDoppler.Projects\n    iex> alias ExDoppler.Secrets\n    iex> [project | _] = Projects.list_projects!()\n    iex> [config | _] = Configs.list_configs!(project)\n    iex> {:ok, _secrets} = Secrets.list_secrets(config)","ref":"ExDoppler.Secrets.html#list_secrets/2-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Secrets.list_secrets/2","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/secrets-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Secrets.html#list_secrets/2-resources"},{"type":"function","title":"ExDoppler.Secrets.list_secrets!/2","doc":"Same as `list_secrets/2` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Secrets.html#list_secrets!/2"},{"type":"function","title":"ExDoppler.Secrets.update_secret/4","doc":"Updates a `ExDoppler.Secret`\n\n<!-- tabs-open -->","ref":"ExDoppler.Secrets.html#update_secret/4"},{"type":"function","title":"🏷️ Params - ExDoppler.Secrets.update_secret/4","doc":"* **config** - Config to get secrets from (e.g `%Config{name: \"dev_personal\", project: \"example-project\" ...}`)\n * **secret_name** - Name of this secret\n * **value** - Value of this secret\n * **opts**: Optional modifications\n    * **visibility** - how the secret should appear - `:masked`, `:unmasked`, or `:restricted`. Default: `:masked`\n    * **should_promote** - Defaults to false. Can only be set to true if the config being updated is a branch config. If set to true, the provided secret will be set in both the branch config as well as the root config in that environment.\n    * **should_delete** - Defaults to false. If set to true, will delete the secret matching the name field.\n    * **should_converge** - Defaults to false. Can only be set to true if the config being updated is a branch config and there is a secret with the same name in the root config. In this case, the branch secret will inherit the value and visibility type from the root secret.","ref":"ExDoppler.Secrets.html#update_secret/4-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Secrets.update_secret/4","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.Secret{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Secrets.html#update_secret/4-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Secrets.update_secret/4","doc":"iex> alias ExDoppler.Config\n    iex> alias ExDoppler.Secrets\n    iex> _ = Secrets.delete_secret!(%Config{name: \"dev_personal\", project: \"example-project\"}, \"DOC_URL\")\n    iex> {:ok, _secret} = Secrets.create_secret(%Config{name: \"dev_personal\", project: \"example-project\"}, \"DOC_URL\", \"example.com\")\n    iex> {:ok, _secret} = Secrets.update_secret(%Config{name: \"dev_personal\", project: \"example-project\"}, \"DOC_URL\", \"example.com2\", visibility: :unmasked)\n    iex> :ok = Secrets.delete_secret!(%Config{name: \"dev_personal\", project: \"example-project\"}, \"DOC_URL\")","ref":"ExDoppler.Secrets.html#update_secret/4-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Secrets.update_secret/4","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/secrets-update){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Secrets.html#update_secret/4-resources"},{"type":"function","title":"ExDoppler.Secrets.update_secret!/4","doc":"Same as `update_secret/4` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Secrets.html#update_secret!/4"},{"type":"function","title":"ExDoppler.Secrets.update_secret_note/3","doc":"Updates the `note` field on a  `ExDoppler.Secret`\n\n<!-- tabs-open -->","ref":"ExDoppler.Secrets.html#update_secret_note/3"},{"type":"function","title":"🏷️ Params - ExDoppler.Secrets.update_secret_note/3","doc":"* **project_name** - Name of the associated project (e.g `\"example-project\"`)\n * **secret_name** - Name of this secret\n * **note** - Attached Note","ref":"ExDoppler.Secrets.html#update_secret_note/3-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Secrets.update_secret_note/3","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %{note: note secret: %ExDoppler.Secret{...}}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Secrets.html#update_secret_note/3-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Secrets.update_secret_note/3","doc":"iex> alias ExDoppler.Config\n    iex> alias ExDoppler.Secrets\n    iex> _ = Secrets.delete_secret!(%Config{name: \"dev_personal\", project: \"example-project\"}, \"DOC_URL\")\n    iex> {:ok, _secret} = Secrets.create_secret(%Config{name: \"dev_personal\", project: \"example-project\"}, \"DOC_URL\", \"example.com\")\n    iex> {:ok, _secret} = Secrets.update_secret_note(\"example-project\", \"DOC_URL\", \"a new note\")\n    iex> :ok = Secrets.delete_secret!(%Config{name: \"dev_personal\", project: \"example-project\"}, \"DOC_URL\")","ref":"ExDoppler.Secrets.html#update_secret_note/3-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Secrets.update_secret_note/3","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/secrets-update_note){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Secrets.html#update_secret_note/3-resources"},{"type":"function","title":"ExDoppler.Secrets.update_secret_note!/3","doc":"Same as `update_secret_note/3` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Secrets.html#update_secret_note!/3"},{"type":"module","title":"ExDoppler.ServiceAccounts","doc":"Module for interacting with `ExDoppler.ServiceAccount`\n\n<!-- tabs-open -->","ref":"ExDoppler.ServiceAccounts.html"},{"type":"module","title":"📖 Resources - ExDoppler.ServiceAccounts","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/service-accounts){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/service_accounts-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.ServiceAccounts.html#module-resources"},{"type":"function","title":"ExDoppler.ServiceAccounts.list_service_accounts/1","doc":"Lists `ExDoppler.ServiceAccount` using pagination.\n\n<!-- tabs-open -->","ref":"ExDoppler.ServiceAccounts.html#list_service_accounts/1"},{"type":"function","title":"🏷️ Params - ExDoppler.ServiceAccounts.list_service_accounts/1","doc":"* **opts**: Optional modifications to the list call\n    * **page** - which page to list (starts at 1) (e.g `page: 2`). Default: `1`\n    * **per_page** - the number of `ExDoppler.ServiceAccount` to return for this page (e.g `per_page: 50`). Default: `20`","ref":"ExDoppler.ServiceAccounts.html#list_service_accounts/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.ServiceAccounts.list_service_accounts/1","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, [%ExDoppler.ServiceAccount{...} ...]}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.ServiceAccounts.html#list_service_accounts/1-returns"},{"type":"function","title":"📖 Resources - ExDoppler.ServiceAccounts.list_service_accounts/1","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/service_accounts-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.ServiceAccounts.html#list_service_accounts/1-resources"},{"type":"function","title":"ExDoppler.ServiceAccounts.list_service_accounts!/1","doc":"Same as `list_service_accounts/1` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.ServiceAccounts.html#list_service_accounts!/1"},{"type":"module","title":"ExDoppler.ServiceTokens","doc":"Module for interacting with `ExDoppler.ServiceToken`\n\n<!-- tabs-open -->","ref":"ExDoppler.ServiceTokens.html"},{"type":"module","title":"📖 Resources - ExDoppler.ServiceTokens","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/service-tokens){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/service_tokens-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.ServiceTokens.html#module-resources"},{"type":"function","title":"ExDoppler.ServiceTokens.create_service_token/3","doc":"Creates a new `ExDoppler.ServiceToken`, given a Config, a name and optional modifications\n\n<!-- tabs-open -->","ref":"ExDoppler.ServiceTokens.html#create_service_token/3"},{"type":"function","title":"🏷️ Params - ExDoppler.ServiceTokens.create_service_token/3","doc":"* **config** - Config associated with the tokens (e.g `%Config{name: \"dev_personal\", project: \"example-project\" ...}`)\n  * **service_token_name**: Name of this token (e.g `\"cli_token\"`)\n  * **opts**: Optional modifications to the list call\n    * **expire_at** - Unix timestamp of when token should expire. Default: `nil`\n    * **access** - Token's capabilities. `\"read\"` or `\"read/write\"`. Default: `\"read\"`","ref":"ExDoppler.ServiceTokens.html#create_service_token/3-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.ServiceTokens.create_service_token/3","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.ServiceToken{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.ServiceTokens.html#create_service_token/3-returns"},{"type":"function","title":"💻 Examples - ExDoppler.ServiceTokens.create_service_token/3","doc":"iex> alias ExDoppler.Config\n    iex> alias ExDoppler.ServiceToken\n    iex> alias ExDoppler.ServiceTokens\n    iex> config = %Config{name: \"dev\", project: \"example-project\"}\n    iex> token_slug = \"my-service-token\"\n    iex> _ = ServiceTokens.delete_service_token!(%ServiceToken{project: config.project, config: config.name, slug: token_slug})\n    iex> {:ok, service_token} = ServiceTokens.create_service_token(config, token_slug)\n    iex> :ok = ServiceTokens.delete_service_token!(service_token)","ref":"ExDoppler.ServiceTokens.html#create_service_token/3-examples"},{"type":"function","title":"📖 Resources - ExDoppler.ServiceTokens.create_service_token/3","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/service_tokens-create){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.ServiceTokens.html#create_service_token/3-resources"},{"type":"function","title":"ExDoppler.ServiceTokens.create_service_token!/3","doc":"Same as `create_service_token/3` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.ServiceTokens.html#create_service_token!/3"},{"type":"function","title":"ExDoppler.ServiceTokens.delete_service_token/1","doc":"Deletes a `ExDoppler.ServiceToken`\n\n<!-- tabs-open -->","ref":"ExDoppler.ServiceTokens.html#delete_service_token/1"},{"type":"function","title":"🏷️ Params - ExDoppler.ServiceTokens.delete_service_token/1","doc":"* **service_token**: The token to delete (e.g `%ServiceToken{project: \"example-project\", config: \"dev_personal\", slug: \"56c69f96-3045-11ea-978f-2e728ce8812\"}`)","ref":"ExDoppler.ServiceTokens.html#delete_service_token/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.ServiceTokens.delete_service_token/1","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, {:success, true}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.ServiceTokens.html#delete_service_token/1-returns"},{"type":"function","title":"💻 Examples - ExDoppler.ServiceTokens.delete_service_token/1","doc":"iex> alias ExDoppler.Config\n    iex> alias ExDoppler.ServiceToken\n    iex> alias ExDoppler.ServiceTokens\n    iex> config = %Config{name: \"dev\", project: \"example-project\"}\n    iex> token_slug = \"my-service-token\"\n    iex> _ = ServiceTokens.delete_service_token!(%ServiceToken{project: config.project, config: config.name, slug: token_slug})\n    iex> {:ok, service_token} = ServiceTokens.create_service_token(config, token_slug)\n    iex> :ok = ServiceTokens.delete_service_token!(service_token)","ref":"ExDoppler.ServiceTokens.html#delete_service_token/1-examples"},{"type":"function","title":"📖 Resources - ExDoppler.ServiceTokens.delete_service_token/1","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/service_tokens-delete){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.ServiceTokens.html#delete_service_token/1-resources"},{"type":"function","title":"ExDoppler.ServiceTokens.delete_service_token!/1","doc":"Same as `delete_service_token/1` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.ServiceTokens.html#delete_service_token!/1"},{"type":"function","title":"ExDoppler.ServiceTokens.list_service_tokens/1","doc":"Lists `ExDoppler.ServiceAccount`\n\n<!-- tabs-open -->","ref":"ExDoppler.ServiceTokens.html#list_service_tokens/1"},{"type":"function","title":"🏷️ Params - ExDoppler.ServiceTokens.list_service_tokens/1","doc":"* **config** - Config associated with the tokens (e.g `%Config{name: \"dev_personal\", project: \"example-project\" ...}`)","ref":"ExDoppler.ServiceTokens.html#list_service_tokens/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.ServiceTokens.list_service_tokens/1","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, [%ExDoppler.ServiceToken{...} ...]}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.ServiceTokens.html#list_service_tokens/1-returns"},{"type":"function","title":"💻 Examples - ExDoppler.ServiceTokens.list_service_tokens/1","doc":"iex> alias ExDoppler.Config\n    iex> alias ExDoppler.ServiceTokens\n    iex> config = %Config{name: \"dev\", project: \"example-project\"}\n    iex> {:ok, _tokens} = ServiceTokens.list_service_tokens(config)","ref":"ExDoppler.ServiceTokens.html#list_service_tokens/1-examples"},{"type":"function","title":"📖 Resources - ExDoppler.ServiceTokens.list_service_tokens/1","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/service_tokens-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.ServiceTokens.html#list_service_tokens/1-resources"},{"type":"function","title":"ExDoppler.ServiceTokens.list_service_tokens!/1","doc":"Same as `list_service_tokens/1` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.ServiceTokens.html#list_service_tokens!/1"},{"type":"module","title":"ExDoppler.Shares","doc":"Module for interacting with `ExDoppler.Share`\n\n<!-- tabs-open -->","ref":"ExDoppler.Shares.html"},{"type":"module","title":"📖 Resources - ExDoppler.Shares","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/share-security){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/share-secret){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Shares.html#module-resources"},{"type":"function","title":"ExDoppler.Shares.plain_text/2","doc":"Creates a plain-text share link `ExDoppler.Share`\n\n<!-- tabs-open -->","ref":"ExDoppler.Shares.html#plain_text/2"},{"type":"function","title":"🏷️ Params - ExDoppler.Shares.plain_text/2","doc":"* **text_to_share** - Plain text to share (e.g `\"sharing this string\"`)\n  * **opts**: Optional modifications\n    * **expire_days** - Days until the link is inaccessible. Default: `90`\n    * **expire_views** - Number of views until the link is inaccessible. -1 means infinite. Default: `-1`","ref":"ExDoppler.Shares.html#plain_text/2-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Shares.plain_text/2","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.Share{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Shares.html#plain_text/2-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Shares.plain_text/2","doc":"iex> alias ExDoppler.Shares\n    iex> {:ok, _share} = Shares.plain_text(\"SHARE_THIS_TEXT\", expire_days: 1, expire_views: 1)","ref":"ExDoppler.Shares.html#plain_text/2-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Shares.plain_text/2","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/share-secret){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Shares.html#plain_text/2-resources"},{"type":"function","title":"ExDoppler.Shares.plain_text!/2","doc":"Same as `plain_text/2` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Shares.html#plain_text!/2"},{"type":"module","title":"ExDoppler.Webhooks","doc":"Module for interacting with `ExDoppler.Webhook`\n\n<!-- tabs-open -->","ref":"ExDoppler.Webhooks.html"},{"type":"module","title":"📖 Resources - ExDoppler.Webhooks","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/webhooks){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/webhooks-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Webhooks.html#module-resources"},{"type":"function","title":"ExDoppler.Webhooks.create_webhook/3","doc":"Creates a new `ExDoppler.Webhook`, given a project, a webhook URL, and options\n\n<!-- tabs-open -->","ref":"ExDoppler.Webhooks.html#create_webhook/3"},{"type":"function","title":"🏷️ Params - ExDoppler.Webhooks.create_webhook/3","doc":"* **project** -  The `ExDoppler.Project` for which you want the webhooks (e.g `%Project{name: \"example-project\"}`)\n  * **url**: The webhook URL. Must be https (e.g `\"https://httpbin.org/post\"`)\n  * **opts**: Optional modifications\n    * **name** - The name of the webhook (e.g \"`my-web-hook\"`)\n    * **secret** - See https://docs.doppler.com/docs/webhooks#verify-webhook-with-request-signing\n    * **payload** - See https://docs.doppler.com/docs/webhooks#default-payload\n    * **enable_configs** - List of Config slugs that the webhook should be enabled for. Default: `[]`\n    * **authentication** - Either `%{type: :Bearer, token: \"BEARER TOKEN HERE\"}` or `%{type: :Basic, username: \"example_user\", password: \"pass\"}`","ref":"ExDoppler.Webhooks.html#create_webhook/3-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Webhooks.create_webhook/3","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.Webhook{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Webhooks.html#create_webhook/3-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Webhooks.create_webhook/3","doc":"iex> alias ExDoppler.Project\n    iex> alias ExDoppler.Webhook\n    iex> alias ExDoppler.Webhooks\n    iex> _ = Webhooks.delete_webhook!(%Project{name: \"example-project\"}, %Webhook{id: \"doc-webhook\"})\n    iex> {:ok, webhook} = Webhooks.create_webhook(%Project{name: \"example-project\"}, \"https://httpbin.org/post\", name: \"doc-webhook\", enable_configs: [\"dev\"], authentication: %{type: :Basic, username: \"joe\", password: \"dirt\"})\n    iex> :ok = Webhooks.delete_webhook!(%Project{name: \"example-project\"}, webhook)","ref":"ExDoppler.Webhooks.html#create_webhook/3-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Webhooks.create_webhook/3","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/webhooks-add){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Webhooks.html#create_webhook/3-resources"},{"type":"function","title":"ExDoppler.Webhooks.create_webhook!/3","doc":"Same as `create_webhook/3` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Webhooks.html#create_webhook!/3"},{"type":"function","title":"ExDoppler.Webhooks.delete_webhook/2","doc":"Deletes a `ExDoppler.Webhook`\n\n<!-- tabs-open -->","ref":"ExDoppler.Webhooks.html#delete_webhook/2"},{"type":"function","title":"🏷️ Params - ExDoppler.Webhooks.delete_webhook/2","doc":"* **project** -  The `ExDoppler.Project` for which you want the webhooks (e.g `%Project{name: \"example-project\"}`)","ref":"ExDoppler.Webhooks.html#delete_webhook/2-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Webhooks.delete_webhook/2","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, {:success, true}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Webhooks.html#delete_webhook/2-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Webhooks.delete_webhook/2","doc":"iex> alias ExDoppler.Project\n    iex> alias ExDoppler.Webhook\n    iex> alias ExDoppler.Webhooks\n    iex> _ = Webhooks.delete_webhook!(%Project{name: \"example-project\"}, %Webhook{id: \"doc-webhook\"})\n    iex> {:ok, webhook} = Webhooks.create_webhook(%Project{name: \"example-project\"}, \"https://httpbin.org/post\", name: \"doc-webhook\", enable_configs: [\"dev\"], authentication: %{type: :Basic, username: \"joe\", password: \"dirt\"})\n    iex> :ok = Webhooks.delete_webhook!(%Project{name: \"example-project\"}, webhook)","ref":"ExDoppler.Webhooks.html#delete_webhook/2-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Webhooks.delete_webhook/2","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/webhooks-delete){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Webhooks.html#delete_webhook/2-resources"},{"type":"function","title":"ExDoppler.Webhooks.delete_webhook!/2","doc":"Same as `delete_webhook/2` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Webhooks.html#delete_webhook!/2"},{"type":"function","title":"ExDoppler.Webhooks.disable_webhook/2","doc":"Disables a `ExDoppler.Webhook`, given a project and a webhook\n\n<!-- tabs-open -->","ref":"ExDoppler.Webhooks.html#disable_webhook/2"},{"type":"function","title":"🏷️ Params - ExDoppler.Webhooks.disable_webhook/2","doc":"* **project** -  The `ExDoppler.Project` for which you want the webhooks (e.g `%Project{name: \"example-project\"}`)\n  * **webhook** - The `ExDoppler.Webhook` to enable (e.g %Webhook{id: \"my-new-webhook\" ...}","ref":"ExDoppler.Webhooks.html#disable_webhook/2-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Webhooks.disable_webhook/2","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.Webhook{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Webhooks.html#disable_webhook/2-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Webhooks.disable_webhook/2","doc":"iex> alias ExDoppler.Project\n    iex> alias ExDoppler.Webhook\n    iex> alias ExDoppler.Webhooks\n    iex> _ = Webhooks.delete_webhook!(%Project{name: \"example-project\"}, %Webhook{id: \"doc-webhook\"})\n    iex> {:ok, webhook} = Webhooks.create_webhook(%Project{name: \"example-project\"}, \"https://httpbin.org/post\", name: \"doc-webhook\", enable_configs: [\"dev\"], authentication: %{type: :Basic, username: \"joe\", password: \"dirt\"})\n    iex> {:ok, %Webhook{enabled: false}} = Webhooks.disable_webhook(%Project{name: \"example-project\"}, webhook)\n    iex> :ok = Webhooks.delete_webhook!(%Project{name: \"example-project\"}, webhook)","ref":"ExDoppler.Webhooks.html#disable_webhook/2-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Webhooks.disable_webhook/2","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/webhooks-disable){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Webhooks.html#disable_webhook/2-resources"},{"type":"function","title":"ExDoppler.Webhooks.disable_webhook!/2","doc":"Same as `disable_webhook/2` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Webhooks.html#disable_webhook!/2"},{"type":"function","title":"ExDoppler.Webhooks.enable_webhook/2","doc":"Enables a `ExDoppler.Webhook`, given a project and a webhook\n\n<!-- tabs-open -->","ref":"ExDoppler.Webhooks.html#enable_webhook/2"},{"type":"function","title":"🏷️ Params - ExDoppler.Webhooks.enable_webhook/2","doc":"* **project** -  The `ExDoppler.Project` for which you want the webhooks (e.g `%Project{name: \"example-project\"}`)\n  * **webhook** - The `ExDoppler.Webhook` to enable (e.g %Webhook{id: \"my-new-webhook\" ...}","ref":"ExDoppler.Webhooks.html#enable_webhook/2-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Webhooks.enable_webhook/2","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.Webhook{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Webhooks.html#enable_webhook/2-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Webhooks.enable_webhook/2","doc":"iex> alias ExDoppler.Project\n    iex> alias ExDoppler.Webhook\n    iex> alias ExDoppler.Webhooks\n    iex> _ = Webhooks.delete_webhook!(%Project{name: \"example-project\"}, %Webhook{id: \"doc-webhook\"})\n    iex> {:ok, webhook} = Webhooks.create_webhook(%Project{name: \"example-project\"}, \"https://httpbin.org/post\", name: \"doc-webhook\", enable_configs: [\"dev\"], authentication: %{type: :Basic, username: \"joe\", password: \"dirt\"})\n    iex> {:ok, %Webhook{enabled: true}} = Webhooks.enable_webhook(%Project{name: \"example-project\"}, webhook)\n    iex> :ok = Webhooks.delete_webhook!(%Project{name: \"example-project\"}, webhook)","ref":"ExDoppler.Webhooks.html#enable_webhook/2-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Webhooks.enable_webhook/2","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/webhooks-enable){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Webhooks.html#enable_webhook/2-resources"},{"type":"function","title":"ExDoppler.Webhooks.enable_webhook!/2","doc":"Same as `enable_webhook/2` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Webhooks.html#enable_webhook!/2"},{"type":"function","title":"ExDoppler.Webhooks.get_webhook/2","doc":"Retrieves a `ExDoppler.Webhook`, given a project and a webhook id\n\n<!-- tabs-open -->","ref":"ExDoppler.Webhooks.html#get_webhook/2"},{"type":"function","title":"🏷️ Params - ExDoppler.Webhooks.get_webhook/2","doc":"* **project** -  The `ExDoppler.Project` for which you want the webhooks (e.g `%Project{name: \"example-project\"}`)\n  * **id** - ID of the webhook to retrieve","ref":"ExDoppler.Webhooks.html#get_webhook/2-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Webhooks.get_webhook/2","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.Webhook{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Webhooks.html#get_webhook/2-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Webhooks.get_webhook/2","doc":"iex> alias ExDoppler.Project\n    iex> alias ExDoppler.Webhook\n    iex> alias ExDoppler.Webhooks\n    iex> _ = Webhooks.delete_webhook!(%Project{name: \"example-project\"}, %Webhook{id: \"doc-webhook\"})\n    iex> {:ok, webhook} = Webhooks.create_webhook(%Project{name: \"example-project\"}, \"https://httpbin.org/post\", name: \"doc-webhook\", enable_configs: [\"dev\"], authentication: %{type: :Basic, username: \"joe\", password: \"dirt\"})\n    iex> {:ok, webhook} = Webhooks.get_webhook(%Project{name: \"example-project\"}, webhook.id)\n    iex> :ok = Webhooks.delete_webhook!(%Project{name: \"example-project\"}, webhook)","ref":"ExDoppler.Webhooks.html#get_webhook/2-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Webhooks.get_webhook/2","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/webhooks-get){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Webhooks.html#get_webhook/2-resources"},{"type":"function","title":"ExDoppler.Webhooks.get_webhook!/2","doc":"Same as `get_webhook/2` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Webhooks.html#get_webhook!/2"},{"type":"function","title":"ExDoppler.Webhooks.list_webhooks/1","doc":"Lists `ExDoppler.Webhook`\n\n<!-- tabs-open -->","ref":"ExDoppler.Webhooks.html#list_webhooks/1"},{"type":"function","title":"🏷️ Params - ExDoppler.Webhooks.list_webhooks/1","doc":"* **project** -  The `ExDoppler.Project` for which you want the webhooks (e.g `%Project{name: \"example-project\"}`)","ref":"ExDoppler.Webhooks.html#list_webhooks/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Webhooks.list_webhooks/1","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, [%ExDoppler.Webhook{...} ...]}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Webhooks.html#list_webhooks/1-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Webhooks.list_webhooks/1","doc":"iex> alias ExDoppler.Project\n    iex> alias ExDoppler.Webhooks\n    iex> {:ok, _webhooks} = Webhooks.list_webhooks(%Project{name: \"example-project\"})","ref":"ExDoppler.Webhooks.html#list_webhooks/1-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Webhooks.list_webhooks/1","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/webhooks-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Webhooks.html#list_webhooks/1-resources"},{"type":"function","title":"ExDoppler.Webhooks.list_webhooks!/1","doc":"Same as `list_webhooks/1` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Webhooks.html#list_webhooks!/1"},{"type":"module","title":"ExDoppler.WorkplaceRoles","doc":"Module for interacting with `ExDoppler.WorkplaceRole`\n\n<!-- tabs-open -->","ref":"ExDoppler.WorkplaceRoles.html"},{"type":"module","title":"📖 Resources - ExDoppler.WorkplaceRoles","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/custom-roles){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/workplace_roles-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.WorkplaceRoles.html#module-resources"},{"type":"function","title":"ExDoppler.WorkplaceRoles.get_workplace_role/1","doc":"Retrieves a `ExDoppler.WorkplaceRole`, given a project and a webhook id\n\n<!-- tabs-open -->","ref":"ExDoppler.WorkplaceRoles.html#get_workplace_role/1"},{"type":"function","title":"🏷️ Params - ExDoppler.WorkplaceRoles.get_workplace_role/1","doc":"* **id** - ID of the role to retrieve","ref":"ExDoppler.WorkplaceRoles.html#get_workplace_role/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.WorkplaceRoles.get_workplace_role/1","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.WorkplaceRole{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.WorkplaceRoles.html#get_workplace_role/1-returns"},{"type":"function","title":"💻 Examples - ExDoppler.WorkplaceRoles.get_workplace_role/1","doc":"iex> alias ExDoppler.WorkplaceRoles\n    iex> {:ok, _role} = WorkplaceRoles.get_workplace_role(\"owner\")","ref":"ExDoppler.WorkplaceRoles.html#get_workplace_role/1-examples"},{"type":"function","title":"📖 Resources - ExDoppler.WorkplaceRoles.get_workplace_role/1","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/workplace_roles-get){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.WorkplaceRoles.html#get_workplace_role/1-resources"},{"type":"function","title":"ExDoppler.WorkplaceRoles.get_workplace_role!/1","doc":"Same as `get_workplace_role/1` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.WorkplaceRoles.html#get_workplace_role!/1"},{"type":"function","title":"ExDoppler.WorkplaceRoles.list_workplace_roles/0","doc":"Lists `ExDoppler.WorkplaceRole`\n\n<!-- tabs-open -->","ref":"ExDoppler.WorkplaceRoles.html#list_workplace_roles/0"},{"type":"function","title":"⤵️ Returns - ExDoppler.WorkplaceRoles.list_workplace_roles/0","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, [%ExDoppler.WorkplaceRole{...} ...]}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.WorkplaceRoles.html#list_workplace_roles/0-returns"},{"type":"function","title":"💻 Examples - ExDoppler.WorkplaceRoles.list_workplace_roles/0","doc":"iex> alias ExDoppler.WorkplaceRoles\n    iex> {:ok, _roles} = WorkplaceRoles.list_workplace_roles()","ref":"ExDoppler.WorkplaceRoles.html#list_workplace_roles/0-examples"},{"type":"function","title":"📖 Resources - ExDoppler.WorkplaceRoles.list_workplace_roles/0","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/workplace_roles-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.WorkplaceRoles.html#list_workplace_roles/0-resources"},{"type":"function","title":"ExDoppler.WorkplaceRoles.list_workplace_roles!/0","doc":"Same as `list_workplace_roles/0` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.WorkplaceRoles.html#list_workplace_roles!/0"},{"type":"module","title":"ExDoppler.WorkplaceUsers","doc":"Module for interacting with `ExDoppler.WorkplaceUser`\n\n<!-- tabs-open -->","ref":"ExDoppler.WorkplaceUsers.html"},{"type":"module","title":"📖 Resources - ExDoppler.WorkplaceUsers","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/workplace-team#user-management){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/users-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.WorkplaceUsers.html#module-resources"},{"type":"function","title":"ExDoppler.WorkplaceUsers.get_workplace_user/1","doc":"Retrieves a `ExDoppler.WorkplaceUser`, given a project and a webhook id\n\n<!-- tabs-open -->","ref":"ExDoppler.WorkplaceUsers.html#get_workplace_user/1"},{"type":"function","title":"🏷️ Params - ExDoppler.WorkplaceUsers.get_workplace_user/1","doc":"* **id** - ID of the Workplace User to retrieve","ref":"ExDoppler.WorkplaceUsers.html#get_workplace_user/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.WorkplaceUsers.get_workplace_user/1","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.WorkplaceUser{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.WorkplaceUsers.html#get_workplace_user/1-returns"},{"type":"function","title":"💻 Examples - ExDoppler.WorkplaceUsers.get_workplace_user/1","doc":"iex> alias ExDoppler.WorkplaceUsers\n    iex> {:ok, [user | _]} = WorkplaceUsers.list_workplace_users()\n    iex> {:ok, _user} = WorkplaceUsers.get_workplace_user(user.id)","ref":"ExDoppler.WorkplaceUsers.html#get_workplace_user/1-examples"},{"type":"function","title":"📖 Resources - ExDoppler.WorkplaceUsers.get_workplace_user/1","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/users-get){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.WorkplaceUsers.html#get_workplace_user/1-resources"},{"type":"function","title":"ExDoppler.WorkplaceUsers.get_workplace_user!/1","doc":"Same as `get_workplace_user/1` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.WorkplaceUsers.html#get_workplace_user!/1"},{"type":"function","title":"ExDoppler.WorkplaceUsers.list_workplace_users/1","doc":"Lists `ExDoppler.WorkplaceUser` using pagination.\n\n<!-- tabs-open -->","ref":"ExDoppler.WorkplaceUsers.html#list_workplace_users/1"},{"type":"function","title":"🏷️ Params - ExDoppler.WorkplaceUsers.list_workplace_users/1","doc":"* **opts**: Optional modifications to the list call\n    * **page** - which page to list (starts at 1) (e.g `page: 2`). Default: `1`\n    * **email** - Filter results to only include the user with the provided email address. Default: `nil`","ref":"ExDoppler.WorkplaceUsers.html#list_workplace_users/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.WorkplaceUsers.list_workplace_users/1","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, [%ExDoppler.WorkplaceUser{...} ...]}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.WorkplaceUsers.html#list_workplace_users/1-returns"},{"type":"function","title":"💻 Examples - ExDoppler.WorkplaceUsers.list_workplace_users/1","doc":"iex> alias ExDoppler.WorkplaceUsers\n    iex> {:ok, _users} = WorkplaceUsers.list_workplace_users()","ref":"ExDoppler.WorkplaceUsers.html#list_workplace_users/1-examples"},{"type":"function","title":"📖 Resources - ExDoppler.WorkplaceUsers.list_workplace_users/1","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/users-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.WorkplaceUsers.html#list_workplace_users/1-resources"},{"type":"function","title":"ExDoppler.WorkplaceUsers.list_workplace_users!/1","doc":"Same as `list_workplace_users/1` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.WorkplaceUsers.html#list_workplace_users!/1"},{"type":"function","title":"ExDoppler.WorkplaceUsers.update_workplace_user/2","doc":"Updates an `ExDoppler.WorkplaceUser`, given a workplace user and new access\n\n<!-- tabs-open -->","ref":"ExDoppler.WorkplaceUsers.html#update_workplace_user/2"},{"type":"function","title":"🏷️ Params - ExDoppler.WorkplaceUsers.update_workplace_user/2","doc":"* **workplace_user**: The relevant environment (e.g `%WorkplaceUser{id: \"98370f9a-0675-430a-abbc-dbb02b78c5a8\" ...}`)\n  * **new_access**: E.g., `:owner`, `:collaborator`, etc.","ref":"ExDoppler.WorkplaceUsers.html#update_workplace_user/2-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.WorkplaceUsers.update_workplace_user/2","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.WorkplaceUser{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.WorkplaceUsers.html#update_workplace_user/2-returns"},{"type":"function","title":"💻 Examples - ExDoppler.WorkplaceUsers.update_workplace_user/2","doc":"iex> alias ExDoppler.WorkplaceUsers\n    iex> {:ok, [user | _]} = WorkplaceUsers.list_workplace_users()\n    iex> {:ok, _user} = WorkplaceUsers.update_workplace_user(user, :owner)","ref":"ExDoppler.WorkplaceUsers.html#update_workplace_user/2-examples"},{"type":"function","title":"📖 Resources - ExDoppler.WorkplaceUsers.update_workplace_user/2","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/users-update){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.WorkplaceUsers.html#update_workplace_user/2-resources"},{"type":"function","title":"ExDoppler.WorkplaceUsers.update_workplace_user!/2","doc":"Same as `update_workplace_user/1` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.WorkplaceUsers.html#update_workplace_user!/2"},{"type":"module","title":"ExDoppler.Workplaces","doc":"Module for interacting with `ExDoppler.Workplace`\n\n<!-- tabs-open -->","ref":"ExDoppler.Workplaces.html"},{"type":"module","title":"📖 Resources - ExDoppler.Workplaces","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/workplace-structure){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/workplace-object){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Workplaces.html#module-resources"},{"type":"function","title":"ExDoppler.Workplaces.get_workplace/0","doc":"Retrieves a `ExDoppler.Workplace`, given options\n\n<!-- tabs-open -->","ref":"ExDoppler.Workplaces.html#get_workplace/0"},{"type":"function","title":"⤵️ Returns - ExDoppler.Workplaces.get_workplace/0","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.Workplace{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Workplaces.html#get_workplace/0-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Workplaces.get_workplace/0","doc":"iex> alias ExDoppler.Workplaces\n    iex> {:ok, _wp} = Workplaces.get_workplace()","ref":"ExDoppler.Workplaces.html#get_workplace/0-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Workplaces.get_workplace/0","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/workplace-get){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Workplaces.html#get_workplace/0-resources"},{"type":"function","title":"ExDoppler.Workplaces.get_workplace!/0","doc":"Same as `get_workplace/0` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Workplaces.html#get_workplace!/0"},{"type":"function","title":"ExDoppler.Workplaces.list_permissions/0","doc":"Lists permissions known in `ExDoppler.Workplace`\n\n<!-- tabs-open -->","ref":"ExDoppler.Workplaces.html#list_permissions/0"},{"type":"function","title":"⤵️ Returns - ExDoppler.Workplaces.list_permissions/0","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, [\"perm1\"...]}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Workplaces.html#list_permissions/0-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Workplaces.list_permissions/0","doc":"iex> alias ExDoppler.Workplaces\n    iex> {:ok, _perms} = Workplaces.list_permissions()","ref":"ExDoppler.Workplaces.html#list_permissions/0-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Workplaces.list_permissions/0","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/workplace_roles-list_permissions){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Workplaces.html#list_permissions/0-resources"},{"type":"function","title":"ExDoppler.Workplaces.list_permissions!/0","doc":"Same as `list_permissions/0` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Workplaces.html#list_permissions!/0"},{"type":"function","title":"ExDoppler.Workplaces.update_workplace/1","doc":"Updates an `ExDoppler.Workplace`\n\n<!-- tabs-open -->","ref":"ExDoppler.Workplaces.html#update_workplace/1"},{"type":"function","title":"🏷️ Params - ExDoppler.Workplaces.update_workplace/1","doc":"* **opts**: Optional modifications\n    * **billing_email** - New billing email for the workplace\n    * **security_email** - New security email for the workplace","ref":"ExDoppler.Workplaces.html#update_workplace/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Workplaces.update_workplace/1","doc":"**✅ On Success**\n\n  ```elixir\n  {:ok, %ExDoppler.Workplace{...}}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  {:err, err}\n  ```","ref":"ExDoppler.Workplaces.html#update_workplace/1-returns"},{"type":"function","title":"💻 Examples - ExDoppler.Workplaces.update_workplace/1","doc":"iex> alias ExDoppler.Workplaces\n    iex> {:ok, wp} = Workplaces.get_workplace()\n    iex> {:ok, _wp} = Workplaces.update_workplace(billing_email: wp.billing_email, security_email: wp.security_email)","ref":"ExDoppler.Workplaces.html#update_workplace/1-examples"},{"type":"function","title":"📖 Resources - ExDoppler.Workplaces.update_workplace/1","doc":"* 📖 [Doppler API docs](https://docs.doppler.com/reference/workplace-update){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Workplaces.html#update_workplace/1-resources"},{"type":"function","title":"ExDoppler.Workplaces.update_workplace!/1","doc":"Same as `update_workplace/1` but won't wrap a successful response in `{:ok, response}`","ref":"ExDoppler.Workplaces.html#update_workplace!/1"},{"type":"module","title":"ExDoppler.ActivityDiff","doc":"Module describing a `diff` to an `ExDoppler.ActivityLog`\n\n<!-- tabs-open -->","ref":"ExDoppler.ActivityDiff.html"},{"type":"module","title":"Fields - ExDoppler.ActivityDiff","doc":"* `added` - Objects added in this Activity (e.g `[\"FOO_BAR\"]`)\n  * `removed` - Objects removed in this Activity (e.g `[\"NEW_SEC2\"]`)\n  * `updated` - Objects updated in this Activity (e.g `[\"HELLO_WORLD\"]`)","ref":"ExDoppler.ActivityDiff.html#module-fields"},{"type":"module","title":"📖 Resources - ExDoppler.ActivityDiff","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/workplace-logs#activity-logs){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/activity_logs-object){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.ActivityDiff.html#module-resources"},{"type":"function","title":"ExDoppler.ActivityDiff.build/1","doc":"Creates an `ActivityDiff` from a map\n\n<!-- tabs-open -->","ref":"ExDoppler.ActivityDiff.html#build/1"},{"type":"function","title":"🏷️ Params - ExDoppler.ActivityDiff.build/1","doc":"* **diff**: Map of fields to turn into an `ActivityDiff`","ref":"ExDoppler.ActivityDiff.html#build/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.ActivityDiff.build/1","doc":"**✅ On Success**\n\n  ```elixir\n  %ExDoppler.ActivityDiff{...}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  raise Error\n  ```\n\n<!-- tabs-close -->","ref":"ExDoppler.ActivityDiff.html#build/1-returns"},{"type":"module","title":"ExDoppler.ActivityLog","doc":"Module describing an ActivityLog\n\n<!-- tabs-open -->","ref":"ExDoppler.ActivityLog.html"},{"type":"module","title":"Fields - ExDoppler.ActivityLog","doc":"* `created_at` - Date and time of the Activity Log's creation (e.g `~U[2025-04-30 10:05:50.040Z]`)\n  * `diff` - Details what was added, removed or updated. See `ExDoppler.ActivityDiff`.\n  * `enclave_config` - Relevant config (e.g `\"github\"`)\n  * `enclave_environment` - Relevant environment (e.g `\"github\"`)\n  * `enclave_project` - Relevant project (e.g `\"example-project\"`)\n  * `html` - HTML rendering of `text`\n  * `text` - Human-readable explanation of the log\n  * `user` - Relevant user to this activity log. See `ExDoppler.User`.","ref":"ExDoppler.ActivityLog.html#module-fields"},{"type":"module","title":"📖 Resources - ExDoppler.ActivityLog","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/workplace-logs#activity-logs){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/activity_logs-object){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.ActivityLog.html#module-resources"},{"type":"function","title":"ExDoppler.ActivityLog.build/1","doc":"Creates an `ActivityLog` from a map\n\n<!-- tabs-open -->","ref":"ExDoppler.ActivityLog.html#build/1"},{"type":"function","title":"🏷️ Params - ExDoppler.ActivityLog.build/1","doc":"* **activity_log**: Map of fields to turn into an `ActivityLog`","ref":"ExDoppler.ActivityLog.html#build/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.ActivityLog.build/1","doc":"**✅ On Success**\n\n  ```elixir\n  %ExDoppler.ActivityLog{...}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  raise Error\n  ```\n\n<!-- tabs-close -->","ref":"ExDoppler.ActivityLog.html#build/1-returns"},{"type":"module","title":"ExDoppler.Config","doc":"Module describing a Conifg\n\n<!-- tabs-open -->","ref":"ExDoppler.Config.html"},{"type":"module","title":"Fields - ExDoppler.Config","doc":"* `created_at` - Date and time of the Config's creation (e.g `~U[2025-04-30 10:05:50.040Z]`)\n  * `environment` - Identifier of the environment that the config belongs to (e.g `\"dev\"`)\n  * `inheritable` - Whether the config can be inherited from (e.g `false`)\n  * `inheriting` - Whether the config is inheriting from another (e.g `false`)\n  * `inherits` - List of configs that the config is inheriting from (e.g `false`)\n  * `initial_fetch_at` - Date and time of the first secrets fetch (e.g `~U[2025-04-30 10:05:50.040Z]`)\n  * `last_fetch_at` - Date and time of the last secrets fetch (e.g `~U[2025-04-30 10:05:50.040Z]`)\n  * `locked` - Whether the config can be renamed and/or deleted (e.g `true`)\n  * `name` - Name of the config (e.g `\"dev_personal\"`)\n  * `project` - Identifier of the project that the config belongs to (e.g `\"example-project\"`)\n  * `root` - Whether the config is the root of the environment (e.g `true`)\n  * `slug` - Unique identifier for this config (e.g `\"00000000-0000-0000-0000-000000000000\"`)","ref":"ExDoppler.Config.html#module-fields"},{"type":"module","title":"📖 Resources - ExDoppler.Config","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/root-configs){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/configs-object){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Config.html#module-resources"},{"type":"function","title":"ExDoppler.Config.build/1","doc":"Creates an `Config` from a map\n\n<!-- tabs-open -->","ref":"ExDoppler.Config.html#build/1"},{"type":"function","title":"🏷️ Params - ExDoppler.Config.build/1","doc":"* **config**: Map of fields to turn into a `Config`","ref":"ExDoppler.Config.html#build/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Config.build/1","doc":"**✅ On Success**\n\n  ```elixir\n  %ExDoppler.Config{...}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  raise Error\n  ```\n\n<!-- tabs-close -->","ref":"ExDoppler.Config.html#build/1-returns"},{"type":"module","title":"ExDoppler.ConfigLog","doc":"Module describing a ConfigLog\n\n<!-- tabs-open -->","ref":"ExDoppler.ConfigLog.html"},{"type":"module","title":"Fields - ExDoppler.ConfigLog","doc":"* `config` - Name of the config (e.g `\"dev_personal\"`)\n  * `created_at` - Date and time of config log's creation (e.g `~U[2025-04-30 10:05:50.040Z]`)\n  * `environment` - Unique identifier for the environment object (e.g `\"dev\"`)\n  * `html` - HTML describing the event.\n  * `id` - Unique identifier for the object (e.g `\"Ul8KeqJzKK3n7OadwqX5RZW2\"`)\n  * `project` - Unique identifier for the project object (e.g `\"example-project\"`)\n  * `rollback` - Whether this config log a rollback of a previous log.\n  * `text` - Text describing the event (e.g `\"Modified secrets and saved to vault\"`)\n  * `user` - Relevant User. See `ExDoppler.User`","ref":"ExDoppler.ConfigLog.html#module-fields"},{"type":"module","title":"📖 Resources - ExDoppler.ConfigLog","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/workplace-logs#config-logs){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/config_logs-object){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.ConfigLog.html#module-resources"},{"type":"function","title":"ExDoppler.ConfigLog.build/1","doc":"Creates an `ConfigLog` from a map\n\n<!-- tabs-open -->","ref":"ExDoppler.ConfigLog.html#build/1"},{"type":"function","title":"🏷️ Params - ExDoppler.ConfigLog.build/1","doc":"* **log**: Map of fields to turn into a `ConfigLog`","ref":"ExDoppler.ConfigLog.html#build/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.ConfigLog.build/1","doc":"**✅ On Success**\n\n  ```elixir\n  %ExDoppler.ConfigLog{...}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  raise Error\n  ```\n\n<!-- tabs-close -->","ref":"ExDoppler.ConfigLog.html#build/1-returns"},{"type":"module","title":"ExDoppler.Environment","doc":"Module describing an Environment\n\n<!-- tabs-open -->","ref":"ExDoppler.Environment.html"},{"type":"module","title":"Fields - ExDoppler.Environment","doc":"* `created_at` - Date and time of environment's creation (e.g `~U[2025-04-30 10:05:50.040Z]`)\n  * `id` - Unique identifier for the object (e.g `\"eot\"`)\n  * `initial_fetch_at` - Date and time of the first secrets fetch from a config in the environment (e.g `~U[2025-04-30 10:05:50.040Z]`)\n  * `name` - Name of the environment.\n  * `project` - Unique identifier for the project object (e.g `\"example-project\"`)\n  * `slug` - Unique identifier for the object (e.g `\"eot\"`)","ref":"ExDoppler.Environment.html#module-fields"},{"type":"module","title":"📖 Resources - ExDoppler.Environment","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/create-project#environments){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/environments-object){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Environment.html#module-resources"},{"type":"function","title":"ExDoppler.Environment.build/1","doc":"Creates an `Environment` from a map\n\n<!-- tabs-open -->","ref":"ExDoppler.Environment.html#build/1"},{"type":"function","title":"🏷️ Params - ExDoppler.Environment.build/1","doc":"* **env**: Map of fields to turn into a `Environment`","ref":"ExDoppler.Environment.html#build/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Environment.build/1","doc":"**✅ On Success**\n\n  ```elixir\n  %ExDoppler.Environment{...}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  raise Error\n  ```\n\n<!-- tabs-close -->","ref":"ExDoppler.Environment.html#build/1-returns"},{"type":"module","title":"ExDoppler.Integration","doc":"Module describing an Integration\n\n<!-- tabs-open -->","ref":"ExDoppler.Integration.html"},{"type":"module","title":"Fields - ExDoppler.Integration","doc":"* `slug` - Unique identifier for the object  (e.g `\"e32d0dcd-c094-4606-aefa-c4127e2a1282\"`)\n  * `name` - Unique identifier for the object (e.g `\"Cloudflare Integration\"`)\n  * `type` - Provider of integration (e.g `\"cloudflare_tokens\"`)\n  * `kind` - Class of integration (e.g `\"rotatedSecrets\"`)\n  * `enabled` - Whether integration is enabled (e.g `true`)\n  * `syncs` - List of Syncs. See `ExDoppler.Sync`","ref":"ExDoppler.Integration.html#module-fields"},{"type":"module","title":"📖 Resources - ExDoppler.Integration","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/integrations){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/integrations-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Integration.html#module-resources"},{"type":"function","title":"ExDoppler.Integration.build/1","doc":"Creates an `Integration` from a map\n\n<!-- tabs-open -->","ref":"ExDoppler.Integration.html#build/1"},{"type":"function","title":"🏷️ Params - ExDoppler.Integration.build/1","doc":"* **integration**: Map of fields to turn into a `Integration`\n\n<!-- tabs-close -->","ref":"ExDoppler.Integration.html#build/1-params"},{"type":"module","title":"ExDoppler.Invite","doc":"Module describing an Invite\n\n<!-- tabs-open -->","ref":"ExDoppler.Invite.html"},{"type":"module","title":"Fields - ExDoppler.Invite","doc":"* `slug` - Unique identifier for the object  (e.g `\"e32d0dcd-c094-4606-aefa-c4127e2a1282\"`)\n  * `email` - Unique identifier for the object (e.g `\"jsmith@example.com\"`)\n  * `created_at` - Date and Time of Invite (e.g ~U[2025-04-30 10:05:50.040Z])\n  * `workplace_role` - See `ExDoppler.WorkplaceRole`","ref":"ExDoppler.Invite.html#module-fields"},{"type":"module","title":"📖 Resources - ExDoppler.Invite","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/workplace-team#send-invite){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/invites-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Invite.html#module-resources"},{"type":"function","title":"ExDoppler.Invite.build/1","doc":"Creates an `Invite` from a map\n\n<!-- tabs-open -->","ref":"ExDoppler.Invite.html#build/1"},{"type":"function","title":"🏷️ Params - ExDoppler.Invite.build/1","doc":"* **invite**: Map of fields to turn into a `Invite`","ref":"ExDoppler.Invite.html#build/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Invite.build/1","doc":"**✅ On Success**\n\n  ```elixir\n  %ExDoppler.Invite{...}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  raise Error\n  ```\n\n<!-- tabs-close -->","ref":"ExDoppler.Invite.html#build/1-returns"},{"type":"module","title":"ExDoppler.ODICToken","doc":"Module describing a [Doppler ODIC](https://docs.doppler.com/reference/auth-oidc){:target=\"_blank\"}\n\n<!-- tabs-open -->","ref":"ExDoppler.ODICToken.html"},{"type":"module","title":"Fields - ExDoppler.ODICToken","doc":"* `token` - ODIC Token\n  * `created_at` - DateTime creation for this token (e.g `~U[2025-04-30 10:05:50.040Z]`)","ref":"ExDoppler.ODICToken.html#module-fields"},{"type":"module","title":"📖 Resources - ExDoppler.ODICToken","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/service-account-identities){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/auth-me){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.ODICToken.html#module-resources"},{"type":"function","title":"ExDoppler.ODICToken.build/1","doc":"Creates a `ODICToken` from a map\n\n<!-- tabs-open -->","ref":"ExDoppler.ODICToken.html#build/1"},{"type":"function","title":"🏷️ Params - ExDoppler.ODICToken.build/1","doc":"* **odic_token**: Map of fields to turn into a `ODICToken`","ref":"ExDoppler.ODICToken.html#build/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.ODICToken.build/1","doc":"**✅ On Success**\n\n  ```elixir\n  %ExDoppler.ODICToken{...}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  raise Error\n  ```\n\n<!-- tabs-close -->","ref":"ExDoppler.ODICToken.html#build/1-returns"},{"type":"module","title":"ExDoppler.Project","doc":"Module describing a Project\n\n<!-- tabs-open -->","ref":"ExDoppler.Project.html"},{"type":"module","title":"Fields - ExDoppler.Project","doc":"* `created_at` - Date and Time of Project creation (e.g `~U[2025-04-30 10:05:50.040Z]`)\n  * `description` - Optional description for Project (e.g `\"my awesome project\"`)\n  * `id` - Unique identifier for the object (e.g `\"jed0c2a68b6\"`)\n  * `name` - Name of the project (e.g `\"example-project\"`)\n  * `slug` - Slug of project (e.g `\"example-project\"`)","ref":"ExDoppler.Project.html#module-fields"},{"type":"module","title":"📖 Resources - ExDoppler.Project","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/create-project){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/projects-object){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Project.html#module-resources"},{"type":"function","title":"ExDoppler.Project.build/1","doc":"Creates an `Project` from a map\n\n<!-- tabs-open -->","ref":"ExDoppler.Project.html#build/1"},{"type":"function","title":"🏷️ Params - ExDoppler.Project.build/1","doc":"* **project**: Map of fields to turn into a `Project`","ref":"ExDoppler.Project.html#build/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Project.build/1","doc":"**✅ On Success**\n\n  ```elixir\n  %ExDoppler.Project{...}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  raise Error\n  ```\n\n<!-- tabs-close -->","ref":"ExDoppler.Project.html#build/1-returns"},{"type":"module","title":"ExDoppler.ProjectMember","doc":"Module describing a ProjectMember\n\n<!-- tabs-open -->","ref":"ExDoppler.ProjectMember.html"},{"type":"module","title":"Fields - ExDoppler.ProjectMember","doc":"* `access_all_environments` - Whether the member can see all environments (e.g `true`)\n  * `environments` - List of environments relevant to the member (e.g `[\"dev\", \"prd\"]`).\n  * `role` - See `ExDoppler.ProjectMemberRole`\n  * `slug` - Unique identifier for project member (e.g `\"e32d0dcd-c094-4606-aefa-c4127e2a1282\"`)\n  * `type` - member type (e.g `\"workplace_user\"`)","ref":"ExDoppler.ProjectMember.html#module-fields"},{"type":"module","title":"📖 Resources - ExDoppler.ProjectMember","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/project-permissions#by-project){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/project_members-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.ProjectMember.html#module-resources"},{"type":"function","title":"ExDoppler.ProjectMember.build/1","doc":"Creates an `ProjectMember` from a map\n\n<!-- tabs-open -->","ref":"ExDoppler.ProjectMember.html#build/1"},{"type":"function","title":"🏷️ Params - ExDoppler.ProjectMember.build/1","doc":"* **member**: Map of fields to turn into a `ProjectMember`","ref":"ExDoppler.ProjectMember.html#build/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.ProjectMember.build/1","doc":"**✅ On Success**\n\n  ```elixir\n  %ExDoppler.ProjectMember{...}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  raise Error\n  ```\n\n<!-- tabs-close -->","ref":"ExDoppler.ProjectMember.html#build/1-returns"},{"type":"module","title":"ExDoppler.ProjectMemberRole","doc":"Module describing a ProjectMemberRole\n\n<!-- tabs-open -->","ref":"ExDoppler.ProjectMemberRole.html"},{"type":"module","title":"Fields - ExDoppler.ProjectMemberRole","doc":"* `identifier` - e.g `\"collaborator\"` or `\"admin\"` or `\"viewer\"` or `\"no_access\"`","ref":"ExDoppler.ProjectMemberRole.html#module-fields"},{"type":"module","title":"📖 Resources - ExDoppler.ProjectMemberRole","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/project-permissions#by-project){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/project_members-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.ProjectMemberRole.html#module-resources"},{"type":"function","title":"ExDoppler.ProjectMemberRole.build/1","doc":"Creates an `ProjectMemberRole` from a map\n\n\n<!-- tabs-open -->","ref":"ExDoppler.ProjectMemberRole.html#build/1"},{"type":"function","title":"🏷️ Params - ExDoppler.ProjectMemberRole.build/1","doc":"* **role**: Map of fields to turn into a `ProjectMemberRole`","ref":"ExDoppler.ProjectMemberRole.html#build/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.ProjectMemberRole.build/1","doc":"**✅ On Success**\n\n  ```elixir\n  %ExDoppler.ProjectMemberRole{...}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  raise Error\n  ```\n\n<!-- tabs-close -->","ref":"ExDoppler.ProjectMemberRole.html#build/1-returns"},{"type":"module","title":"ExDoppler.ProjectRole","doc":"Module describing a Project Role\n\n<!-- tabs-open -->","ref":"ExDoppler.ProjectRole.html"},{"type":"module","title":"Fields - ExDoppler.ProjectRole","doc":"* `created_at` - Date and Time the role was created (e.g `~U[2025-04-30 10:05:50.040Z]`)\n  * `identifier` - List of environments relevant to the member (e.g `[\"dev\", \"prd\"]`).\n  * `is_custom_role` - Whether it's a user made role (e.g `false`)\n  * `name` - Name of role (e.g `\"viewer\"`)\n  * `permissions` - member type (e.g `[\"enclave_config_logs\", \"enclave_project_config_secrets_read\"...]`)","ref":"ExDoppler.ProjectRole.html#module-fields"},{"type":"module","title":"📖 Resources - ExDoppler.ProjectRole","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/project-permissions){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/project_roles-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.ProjectRole.html#module-resources"},{"type":"function","title":"ExDoppler.ProjectRole.build/1","doc":"Creates an `ProjectRole` from a map\n\n<!-- tabs-open -->","ref":"ExDoppler.ProjectRole.html#build/1"},{"type":"function","title":"🏷️ Params - ExDoppler.ProjectRole.build/1","doc":"* **role**: Map of fields to turn into a `ProjectRole`","ref":"ExDoppler.ProjectRole.html#build/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.ProjectRole.build/1","doc":"**✅ On Success**\n\n  ```elixir\n  %ExDoppler.ProjectRole{...}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  raise Error\n  ```\n\n<!-- tabs-close -->","ref":"ExDoppler.ProjectRole.html#build/1-returns"},{"type":"module","title":"ExDoppler.Secret","doc":"Module describing a Secret\n\n<!-- tabs-open -->","ref":"ExDoppler.Secret.html"},{"type":"module","title":"Fields - ExDoppler.Secret","doc":"* `name` - Name of the Secret (e.g `\"API_KEY\"`)\n  * `raw` - Raw value of the Secret\n  * `computed` - Computed value of the Secret\n  * `note` - A descriptive note to the Secret\n  * `raw_visibility` - Raw visibility. `:masked`, `:unmasked`, or `:restricted`\n  * `computed_visibility` - Computed visibility. `:masked`, `:unmasked`, or `:restricted`","ref":"ExDoppler.Secret.html#module-fields"},{"type":"module","title":"📖 Resources - ExDoppler.Secret","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/secrets){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/secrets-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Secret.html#module-resources"},{"type":"function","title":"ExDoppler.Secret.build/1","doc":"Creates an `Secret` from a map\n\n<!-- tabs-open -->","ref":"ExDoppler.Secret.html#build/1"},{"type":"function","title":"🏷️ Params - ExDoppler.Secret.build/1","doc":"* **{name, map}**: The secret's name and map of fields to turn into a `Secret`","ref":"ExDoppler.Secret.html#build/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Secret.build/1","doc":"**✅ On Success**\n\n  ```elixir\n  %ExDoppler.Secret{...}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  raise Error\n  ```\n\n<!-- tabs-close -->","ref":"ExDoppler.Secret.html#build/1-returns"},{"type":"module","title":"ExDoppler.ServiceAccount","doc":"Module describing a Service Account\n\n<!-- tabs-open -->","ref":"ExDoppler.ServiceAccount.html"},{"type":"module","title":"Fields - ExDoppler.ServiceAccount","doc":"* `name` - Name of the Service Account (e.g `\"sa\"`)\n  * `slug` - Unique slug for this Service Account (e.g `\"00000000-0000-0000-0000-000000000000\"`)\n  * `created_at` - Date and Time for this Service Account's creation (e.g `~U[2025-04-30 10:05:50.040Z]`)\n  * `workplace_role` - See `ExDoppler.WorkplaceRole`","ref":"ExDoppler.ServiceAccount.html#module-fields"},{"type":"module","title":"📖 Resources - ExDoppler.ServiceAccount","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/service-accounts){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/service_accounts-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.ServiceAccount.html#module-resources"},{"type":"function","title":"ExDoppler.ServiceAccount.build/1","doc":"Creates an `ServiceAccount` from a map\n\n<!-- tabs-open -->","ref":"ExDoppler.ServiceAccount.html#build/1"},{"type":"function","title":"🏷️ Params - ExDoppler.ServiceAccount.build/1","doc":"* **account**: Map of fields to turn into a `ServiceAccount`","ref":"ExDoppler.ServiceAccount.html#build/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.ServiceAccount.build/1","doc":"**✅ On Success**\n\n  ```elixir\n  %ExDoppler.ServiceAccount{...}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  raise Error\n  ```\n\n<!-- tabs-close -->","ref":"ExDoppler.ServiceAccount.html#build/1-returns"},{"type":"module","title":"ExDoppler.ServiceToken","doc":"Module describing a Service Token\n\n<!-- tabs-open -->","ref":"ExDoppler.ServiceToken.html"},{"type":"module","title":"Fields - ExDoppler.ServiceToken","doc":"* `name` - Name of the service token. (e.g `\"AWS Lambda\"`)\n  * `slug` - Unique slug for this token (e.g `\"00000000-0000-0000-0000-000000000000\"`)\n  * `created_at` - Date and Time for this token's creation (e.g `~U[2025-04-30 10:05:50.040Z]`)\n  * `config` - Config associated with the token (e.g `\"prd_aws\"`)\n  * `environment` - Environment associated with the token (e.g `\"prd\"`)\n  * `expires_at` - Date and Time this token will expire (e.g `~U[2025-04-30 10:05:50.040Z]`)","ref":"ExDoppler.ServiceToken.html#module-fields"},{"type":"module","title":"📖 Resources - ExDoppler.ServiceToken","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/service-tokens){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/service_tokens-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.ServiceToken.html#module-resources"},{"type":"function","title":"ExDoppler.ServiceToken.build/1","doc":"Creates an `ServiceToken` from a map\n\n<!-- tabs-open -->","ref":"ExDoppler.ServiceToken.html#build/1"},{"type":"function","title":"🏷️ Params - ExDoppler.ServiceToken.build/1","doc":"* **token**: Map of fields to turn into a `ServiceToken`","ref":"ExDoppler.ServiceToken.html#build/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.ServiceToken.build/1","doc":"**✅ On Success**\n\n  ```elixir\n  %ExDoppler.ServiceToken{...}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  raise Error\n  ```\n\n<!-- tabs-close -->","ref":"ExDoppler.ServiceToken.html#build/1-returns"},{"type":"module","title":"ExDoppler.Share","doc":"Module describing a Share Link\n\n<!-- tabs-open -->","ref":"ExDoppler.Share.html"},{"type":"module","title":"Fields - ExDoppler.Share","doc":"* `url` - URL to give to the recipient\n  * `authenticated_url` - URL which includes the password (so the user doesn't have to type it in)\n  * `password` - Password to open the secret","ref":"ExDoppler.Share.html#module-fields"},{"type":"module","title":"📖 Resources - ExDoppler.Share","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/share-security){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/share-secret){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Share.html#module-resources"},{"type":"function","title":"ExDoppler.Share.build/1","doc":"Creates an `Share` from a map\n\n<!-- tabs-open -->","ref":"ExDoppler.Share.html#build/1"},{"type":"function","title":"🏷️ Params - ExDoppler.Share.build/1","doc":"* **token**: Map of fields to turn into a `Share`","ref":"ExDoppler.Share.html#build/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Share.build/1","doc":"**✅ On Success**\n\n  ```elixir\n  %ExDoppler.Share{...}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  raise Error\n  ```\n\n<!-- tabs-close -->","ref":"ExDoppler.Share.html#build/1-returns"},{"type":"module","title":"ExDoppler.Sync","doc":"Module describing a Sync\n\n<!-- tabs-open -->","ref":"ExDoppler.Sync.html"},{"type":"module","title":"Fields - ExDoppler.Sync","doc":"* `slug` - Unique identifier for the object  (e.g `\"0cd84923-b8c5-49e6-8713-e6ea2148a6c1\"`)\n  * `enabled` - Whether sync is enabled (e.g `true`)\n  * `last_synced_at` - Date and Time of last sync (e.g `~U[2025-04-30 10:05:50.040Z]`)\n  * `project` - Unique identifier for the project object (e.g `\"example-project\"`)\n  * `config` - Relevant config (e.g `\"prd\"`)\n  * `integration` - Relevant integration slug (e.g `\"e32d0dcd-c094-4606-aefa-c4127e2a1282\"`)","ref":"ExDoppler.Sync.html#module-fields"},{"type":"module","title":"📖 Resources - ExDoppler.Sync","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/integrations){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/syncs-create){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Sync.html#module-resources"},{"type":"function","title":"ExDoppler.Sync.build/1","doc":"Creates an `Sync` from a map\n\n<!-- tabs-open -->","ref":"ExDoppler.Sync.html#build/1"},{"type":"function","title":"🏷️ Params - ExDoppler.Sync.build/1","doc":"* **sync**: Map of fields to turn into a `Sync`","ref":"ExDoppler.Sync.html#build/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Sync.build/1","doc":"**✅ On Success**\n\n  ```elixir\n  %ExDoppler.Sync{...}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  raise Error\n  ```\n\n<!-- tabs-close -->","ref":"ExDoppler.Sync.html#build/1-returns"},{"type":"module","title":"ExDoppler.TokenInfo","doc":"Module describing a [Doppler Me](https://docs.doppler.com/reference/auth-me){:target=\"_blank\"}\n\n<!-- tabs-open -->","ref":"ExDoppler.TokenInfo.html"},{"type":"module","title":"Fields - ExDoppler.TokenInfo","doc":"* `slug` - Unique identifier for this token (e.g `\"00000000-0000-0000-0000-000000000000\"`)\n  * `name` - If given, a human-readable name for this token (e.g `\"my-auth-token\"`)\n  * `created_at` - DateTime creation for this token (e.g `~U[2025-04-30 10:05:50.040Z]`)\n  * `last_seen_at` - DateTime for last use (e.g `~U[2025-04-30 10:05:50.040Z]`)\n  * `type` - Token Type (e.g `\"personal\"`)\n  * `token_preview` - Used when referring to this token (e.g `dp.pt....ABCdEF`)\n  * `workplace` - Relevant `ExDoppler.Workplace`.","ref":"ExDoppler.TokenInfo.html#module-fields"},{"type":"module","title":"📖 Resources - ExDoppler.TokenInfo","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/service-account-identities){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/auth-me){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.TokenInfo.html#module-resources"},{"type":"function","title":"ExDoppler.TokenInfo.build/1","doc":"Creates a `TokenInfo` from a map\n\n<!-- tabs-open -->","ref":"ExDoppler.TokenInfo.html#build/1"},{"type":"function","title":"🏷️ Params - ExDoppler.TokenInfo.build/1","doc":"* **token_info**: Map of fields to turn into a `TokenInfo`","ref":"ExDoppler.TokenInfo.html#build/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.TokenInfo.build/1","doc":"**✅ On Success**\n\n  ```elixir\n  %ExDoppler.TokenInfo{...}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  raise Error\n  ```\n\n<!-- tabs-close -->","ref":"ExDoppler.TokenInfo.html#build/1-returns"},{"type":"module","title":"ExDoppler.User","doc":"Module describing a Doppler User (not to be confused with `ExDoppler.WorkplaceUser`)\n\n<!-- tabs-open -->","ref":"ExDoppler.User.html"},{"type":"module","title":"Fields - ExDoppler.User","doc":"* `email` - User's email (e.g `\"jane.smith@example.com\"`)\n  * `name` - User's name (e.g `\"Jane Smith\"`)\n  * `profile_image_url` - URL to a profile image\n  * `username` - User's username (e.g `\"jsmith\"`)","ref":"ExDoppler.User.html#module-fields"},{"type":"module","title":"📖 Resources - ExDoppler.User","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/workplace-team#user-management){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/users-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.User.html#module-resources"},{"type":"function","title":"ExDoppler.User.build/1","doc":"Creates an `User` from a map\n\n<!-- tabs-open -->","ref":"ExDoppler.User.html#build/1"},{"type":"function","title":"🏷️ Params - ExDoppler.User.build/1","doc":"* **user**: Map of fields to turn into an `User`","ref":"ExDoppler.User.html#build/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.User.build/1","doc":"**✅ On Success**\n\n  ```elixir\n  %ExDoppler.User{...}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  raise Error\n  ```\n\n<!-- tabs-close -->","ref":"ExDoppler.User.html#build/1-returns"},{"type":"module","title":"ExDoppler.Webhook","doc":"Module describing a Webhook\n\n<!-- tabs-open -->","ref":"ExDoppler.Webhook.html"},{"type":"module","title":"Fields - ExDoppler.Webhook","doc":"* `authentication` - See `ExDoppler.WebhookAuth`\n  * `can_manage` - Token in use can manage this webhook (e.g `true`)\n  * `enabled` - Whether webhook is enabled (e.g `true`)\n  * `enabled_configs` - List of configs for which the webhook is active (e.g `[\"dev\", \"github\"]`)\n  * `has_secret` - See https://docs.doppler.com/docs/webhooks#verify-webhook-with-request-signing (e.g `false`)\n  * `id` - Unique ID for webhook, (e.g `\"00000000-0000-0000-0000-000000000000\"`)\n  * `name` - Human readable name for webhook (e.g `\"my-new-webhook\"`)\n  * `url` - Webhook's URL (e.g `\"https://httpbin.org/post\"`)","ref":"ExDoppler.Webhook.html#module-fields"},{"type":"module","title":"📖 Resources - ExDoppler.Webhook","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/webhooks){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/webhooks-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Webhook.html#module-resources"},{"type":"function","title":"ExDoppler.Webhook.build/1","doc":"Creates a `Webhook` from a map\n\n<!-- tabs-open -->","ref":"ExDoppler.Webhook.html#build/1"},{"type":"function","title":"🏷️ Params - ExDoppler.Webhook.build/1","doc":"* **webhook**: Map of fields to turn into a `Webhook`","ref":"ExDoppler.Webhook.html#build/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Webhook.build/1","doc":"**✅ On Success**\n\n  ```elixir\n  %ExDoppler.Webhook{...}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  raise Error\n  ```\n\n<!-- tabs-close -->","ref":"ExDoppler.Webhook.html#build/1-returns"},{"type":"module","title":"ExDoppler.WebhookAuth","doc":"Module describing a WebhookAuth. See `ExDoppler.Webhook`\n\n<!-- tabs-open -->","ref":"ExDoppler.WebhookAuth.html"},{"type":"module","title":"Fields - ExDoppler.WebhookAuth","doc":"* `type` - either `\"Basic\"` or `\"Bearer\"`\n  * `token` - If `type = \"Bearer\"`, the Bearer token\n  * `username` - If `type = \"Basic\"`, the username to use. (e.g `\"joe\"`)\n  * `has_password` - If `type = \"Basic\"`, that there is a password associated. (e.g `false`)","ref":"ExDoppler.WebhookAuth.html#module-fields"},{"type":"module","title":"📖 Resources - ExDoppler.WebhookAuth","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/webhooks){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/webhooks-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.WebhookAuth.html#module-resources"},{"type":"function","title":"ExDoppler.WebhookAuth.build/1","doc":"Creates a `WebhookAuth` from a map\n\n<!-- tabs-open -->","ref":"ExDoppler.WebhookAuth.html#build/1"},{"type":"function","title":"🏷️ Params - ExDoppler.WebhookAuth.build/1","doc":"* **auth**: Map of fields to turn into a `WebhookAuth`","ref":"ExDoppler.WebhookAuth.html#build/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.WebhookAuth.build/1","doc":"**✅ On Success**\n\n  ```elixir\n  %ExDoppler.WebhookAuth{...}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  raise Error\n  ```\n\n<!-- tabs-close -->","ref":"ExDoppler.WebhookAuth.html#build/1-returns"},{"type":"module","title":"ExDoppler.Workplace","doc":"Module describing a Workplace\n\n<!-- tabs-open -->","ref":"ExDoppler.Workplace.html"},{"type":"module","title":"Fields - ExDoppler.Workplace","doc":"* `billing_email` - Email to send billing invoices to.\n  * `name` - Name of the workplace\n  * `security_email` - Email to send security notices to.\n  * `id` - Unique ID for the Workplace(e.g `\"bc391a7dba8924cd9b69\"`)","ref":"ExDoppler.Workplace.html#module-fields"},{"type":"module","title":"📖 Resources - ExDoppler.Workplace","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/workplace-structure){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/workplace-object){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.Workplace.html#module-resources"},{"type":"function","title":"ExDoppler.Workplace.build/1","doc":"Creates a `Workplace` from a map\n\n<!-- tabs-open -->","ref":"ExDoppler.Workplace.html#build/1"},{"type":"function","title":"🏷️ Params - ExDoppler.Workplace.build/1","doc":"* **wp**: Map of fields to turn into a `Workplace`","ref":"ExDoppler.Workplace.html#build/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.Workplace.build/1","doc":"**✅ On Success**\n\n  ```elixir\n  %ExDoppler.Workplace{...}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  raise Error\n  ```\n\n<!-- tabs-close -->","ref":"ExDoppler.Workplace.html#build/1-returns"},{"type":"module","title":"ExDoppler.WorkplaceRole","doc":"Module describing a WorkplaceRole\n\n<!-- tabs-open -->","ref":"ExDoppler.WorkplaceRole.html"},{"type":"module","title":"Fields - ExDoppler.WorkplaceRole","doc":"* `created_at` - Creation Date and Time (e.g `~U[2025-04-30 10:05:50.040Z]`)\n  * `identifier` - ID of the role (e.g `\"admin\"`)\n  * `is_custom_role` - Whether role is custom (e.g `false`)\n  * `is_inline_role` - Whether role is inline (e.g `false`)\n  * `name` - Human readable name (e.g `\"Admin\"`)\n  * `permissions` - see `all_permissions/0`","ref":"ExDoppler.WorkplaceRole.html#module-fields"},{"type":"module","title":"📖 Resources - ExDoppler.WorkplaceRole","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/custom-roles){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/workplace_roles-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.WorkplaceRole.html#module-resources"},{"type":"function","title":"ExDoppler.WorkplaceRole.all_permissions/0","doc":"Returns a list of all possible Workplace Role permissions","ref":"ExDoppler.WorkplaceRole.html#all_permissions/0"},{"type":"function","title":"ExDoppler.WorkplaceRole.build/1","doc":"Creates a `WorkplaceRole` from a map\n\n<!-- tabs-open -->","ref":"ExDoppler.WorkplaceRole.html#build/1"},{"type":"function","title":"🏷️ Params - ExDoppler.WorkplaceRole.build/1","doc":"* **wp_role**: Map of fields to turn into a `WorkplaceRole`","ref":"ExDoppler.WorkplaceRole.html#build/1-params"},{"type":"function","title":"⤵️ Returns - ExDoppler.WorkplaceRole.build/1","doc":"**✅ On Success**\n\n  ```elixir\n  %ExDoppler.WorkplaceRole{...}\n  ```\n\n  **❌ On Failure**\n\n   ```elixir\n  raise Error\n  ```\n\n<!-- tabs-close -->","ref":"ExDoppler.WorkplaceRole.html#build/1-returns"},{"type":"module","title":"ExDoppler.WorkplaceUser","doc":"Module describing a WorkplaceUser\n\n<!-- tabs-open -->","ref":"ExDoppler.WorkplaceUser.html"},{"type":"module","title":"Fields - ExDoppler.WorkplaceUser","doc":"* `access` - level of access this WorkplaceUser has (e.g `\"owner\"`, `\"collaborator\"`, or `\"admin\"`)\n  * `created_at` - DateTime for when this user was created (e.g `~U[2025-04-30 10:05:50.040Z]`)\n  * `id` - Unique Identifier for this user (e.g `\"00000000-0000-0000-0000-000000000000\"`)","ref":"ExDoppler.WorkplaceUser.html#module-fields"},{"type":"module","title":"📖 Resources - ExDoppler.WorkplaceUser","doc":"* 📖 [Doppler docs](https://docs.doppler.com/docs/workplace-team#user-management){:target=\"_blank\"}\n  * 📖 [Doppler API docs](https://docs.doppler.com/reference/users-list){:target=\"_blank\"}\n  * 💬 Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    \n\n<!-- tabs-close -->","ref":"ExDoppler.WorkplaceUser.html#module-resources"},{"type":"function","title":"ExDoppler.WorkplaceUser.build/1","doc":"Creates an `WorkplaceUser` from a map\n\n<!-- tabs-open -->","ref":"ExDoppler.WorkplaceUser.html#build/1"},{"type":"function","title":"🏷️ Params - ExDoppler.WorkplaceUser.build/1","doc":"* **wp_user**: Map of fields to turn into an `User`\n\n<!-- tabs-close -->","ref":"ExDoppler.WorkplaceUser.html#build/1-params"},{"type":"extras","title":"README","doc":"Manage and access your Doppler secrets without leaving Elixir\n \n\n\n \n   \n     \n   \n\n   \n     \n   \n\n  <!--\n   \n     \n   \n  -->","ref":"readme.html"},{"type":"extras","title":"Table of Contents - README","doc":"- [Installation](#installation)\n- [Quick Start](#quick-start)\n- [Mapping](#mapping)\n- [Not Implemented](#not-implemented)","ref":"readme.html#table-of-contents"},{"type":"extras","title":"Installation - README","doc":"Add `:ex_doppler` to your list of deps in `mix.exs`:\n\n```elixir\n{:ex_doppler, \"~> 1.0\"}\n```\n\nThen run `mix deps.get` to install ExDoppler and its dependencies.","ref":"readme.html#installation"},{"type":"extras","title":"Quick Start - README","doc":"1. [Create a Doppler Token](https://docs.doppler.com/docs/service-tokens#creating-service-tokens)\n2. Put your token in your environment (**NEVER** put the token anywhere in your code)\n  ```sh\n  export HISTIGNORE='export DOPPLER_TOKEN*'\n  \n  export DOPPLER_TOKEN='dp.st.prd.xxxx'\n  ```\n3. Use ExDoppler to access your secrets\n  ```elixir\n      secret_value = ExDoppler.get_secret_raw!(\"example-project\", \"dev_personal\", \"DB_URL\")\n  ```\n\n4. You're good to go. I really recommend you have a look at [the docs](https://hexdocs.pm/ex_doppler/)","ref":"readme.html#quick-start"},{"type":"extras","title":"Mapping - README","doc":"| Realm            | Actions Implemented                                                       | ExDoppler Module                   | Notes |\n|------------------|---------------------------------------------------------------------------|------------------------------------|-------|\n| Activity Logs    | List, Retrieve                                                            | `ExDoppler.ActivityLogs`           |       |\n| Auths            | Me, ODIC, Revoke                                                          | `ExDoppler.Auths`                  |       |\n| Config Logs      | List, Retrieve, Rollback                                                  | `ExDoppler.ConfigLogs`             |       |\n| Configs          | List, Retrieve, Create, Rename, Clone, Lock, Unlock, Delete               | `ExDoppler.Configs`                |       |\n| Environments     | List, Retrieve, Create, Update, Delete                                    | `ExDoppler.Environments`           |       |\n| Integrations     | List, Retrieve, Create, Update, Get Options, Delete                       | `ExDoppler.Integrations`           |       |\n| Invites          | List                                                                      | `ExDoppler.Invites`                |       |\n| Project Members  | List, Retrieve                                                            | `ExDoppler.ProjectMembers`         |       |\n| Project Roles    | List, Retrieve, Create                                                    | `ExDoppler.ProjectRoles`           |       |\n| Projects         | List, Retrieve, Create, Update, Delete, List Project Permissions          | `ExDoppler.Projects`               |       |\n| Secret Syncs     | Retrieve, Create, Delete                                                  | `ExDoppler.SecretSyncs`            |       |\n| Secrets          | List, Retrieve, Download, List Names, Create, Update, Update Note, Delete | `ExDoppler` or `ExDoppler.Secrets` |       |\n| Service Accounts | List                                                                      | `ExDoppler.ServiceAccounts`        |       |\n| Service Tokens   | List, Create, Delete                                                      | `ExDoppler.ServiceTokens`          |       |\n| Shares           | Plain Text                                                                | `ExDoppler.Shares`                 |       |\n| Webhooks         | List, Retrieve, Enable, Disable, Create, Delete                           | `ExDoppler.Webhooks`               |       |\n| Workplace Roles  | List, Retrieve                                                            | `ExDoppler.WorkplaceRoles`         |       |\n| Workplace Users  | List, Retrieve, Update                                                    | `ExDoppler.WorkplaceUsers`         |       |\n| Workplace        | Retrieve, Update                                                          | `ExDoppler.Workplaces`             |       |","ref":"readme.html#mapping"},{"type":"extras","title":"Not Implemented - README","doc":"| Realm : Action                                                                                        | Implemented | Notes                                                  |\n|-------------------------------------------------------------------------------------------------------|-------------|--------------------------------------------------------|\n| [Project Roles : Create](https://docs.doppler.com/reference/project_roles-create)                     | ⁉️          | Requires a Team tier                                   |\n| [Project Roles : Update](https://docs.doppler.com/reference/project_roles-update)                     | ⁉️          | Requires a Team tier                                   |\n| [Project Members : Add](https://docs.doppler.com/reference/project_members-add)                       | ⁉️          | Requires a Team tier                                   |\n| [Project Members : Update](https://docs.doppler.com/reference/project_members-update)                 | ⁉️          | Requires a Team tier                                   |\n| [Project Members : Delete](https://docs.doppler.com/reference/project_members-delete)                 | ⁉️          | Requires a Team tier                                   |\n| [Project Roles : Delete](https://docs.doppler.com/reference/project_roles-delete)                     | ⁉️          | Requires a Team tier                                   |\n| [Trusted IPs : List](https://docs.doppler.com/reference/configs-list_trusted_ips)                     | ⁉️          | Requires a Team tier                                   |\n| [Trusted IPs : Add](https://docs.doppler.com/reference/configs-add_trusted_ip)                        | ⁉️          | Requires a Team tier                                   |\n| [Trusted IPs : Delete](https://docs.doppler.com/reference/configs-delete_trusted_ip)                  | ⁉️          | Requires a Team tier                                   |\n| [Groups : List](https://docs.doppler.com/reference/groups-list)                                       | ⁉️          | Requires a Team tier                                   |\n| [Groups : Create](https://docs.doppler.com/reference/groups-create)                                   | ⁉️          | Requires a Team tier                                   |\n| [Groups : Retrieve](https://docs.doppler.com/reference/groups-get)                                    | ⁉️          | Requires a Team tier                                   |\n| [Groups : Update](https://docs.doppler.com/reference/groups-update)                                   | ⁉️          | Requires a Team tier                                   |\n| [Groups : Delete](https://docs.doppler.com/reference/groups-delete)                                   | ⁉️          | Requires a Team tier                                   |\n| [Groups : Add Member](https://docs.doppler.com/reference/groups-add_member)                           | ⁉️          | Requires a Team tier                                   |\n| [Groups : Delete Memeber](https://docs.doppler.com/reference/groups-delete_member)                    | ⁉️          | Requires a Team tier                                   |\n| [Groups : Retrieve Memeber](https://docs.doppler.com/reference/retrieve-member)                       | ⁉️          | Requires a Team tier                                   |\n| [Service Accounts : List](https://docs.doppler.com/reference/service_accounts-list)                   | ⁉️          | Requires a Team tier                                   |\n| [Service Accounts : Create](https://docs.doppler.com/reference/service_accounts-create)               | ⁉️          | Requires a Team tier                                   |\n| [Service Accounts : Retrieve](https://docs.doppler.com/reference/service_accounts-get)                | ⁉️          | Requires a Team tier                                   |\n| [Service Accounts : Update](https://docs.doppler.com/reference/service_accounts-update)               | ⁉️          | Requires a Team tier                                   |\n| [Service Accounts : Delete](https://docs.doppler.com/reference/service_accounts-delete)               | ⁉️          | Requires a Team tier                                   |\n| [Service Account Tokens : List](https://docs.doppler.com/reference/service_account_tokens-list)       | ⁉️          | Requires a Team tier                                   |\n| [Service Account Tokens : Create](https://docs.doppler.com/reference/service_account_tokens-create)   | ⁉️          | Requires a Team tier                                   |\n| [Service Account Tokens : Retrieve](https://docs.doppler.com/reference/service_account_tokens-get)    | ⁉️          | Requires a Team tier                                   |\n| [Service Account Tokens : Delete](https://docs.doppler.com/reference/service_account_tokens-delete)   | ⁉️          | Requires a Team tier                                   |\n| [Webhooks : Update](https://docs.doppler.com/reference/webhooks-update)                               | ⁉️          | It's...complex                                         |\n| [Workplace Roles : Create](https://docs.doppler.com/reference/workplace_roles-create)                 | ⁉️          | Requires a Team tier                                   |\n| [Workplace Roles : Update](https://docs.doppler.com/reference/workplace_roles-update)                 | ⁉️          | Requires a Team tier                                   |\n| [Workplace Roles : Delete](https://docs.doppler.com/reference/workplace_roles-delete)                 | ⁉️          | Requires a Team tier                                   |\n| [Configs : Inheritable](https://docs.doppler.com/reference/configs-inheritable)                       | ⁉️          | Requires a Team tier                                   |\n| [Configs : Inherits](https://docs.doppler.com/reference/configs-inherits)                             | ⁉️          | Requires a Team tier                                   |\n| [Change Request Policies : Create](https://docs.doppler.com/reference/change-request-policies-create) | ⁉️          | Requires a Team tier                                   |\n| [Change Request Policies : Retrieve](https://docs.doppler.com/reference/change-request-policies-get)  | ⁉️          | Requires a Team tier                                   |\n| [Change Request Policies : Update](https://docs.doppler.com/reference/change-request-policies-update) | ⁉️          | Requires a Team tier                                   |\n| [Change Request Policies : Delete](https://docs.doppler.com/reference/change-request-policies-delete) | ⁉️          | Requires a Team tier                                   |\n| [Dynamic Secrets : Issue Lease](https://docs.doppler.com/reference/dynamic_secrets-issue_lease)       | ⁉️          | Requires a Team tier                                   |\n| [Dynamic Secrets : Revoke](https://docs.doppler.com/reference/dynamic_secrets-revoke_lease)           | ⁉️          | Requires a Team tier                                   |\n| [Share : E2E Encrypted](https://docs.doppler.com/reference/share-secret-encrypted)                    | ⁉️          | Spent hours trying to get the link to actually decrypt |","ref":"readme.html#not-implemented"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}